from fastapi import APIRouter
from pydantic import BaseModel
import azure.cosmos.exceptions as exceptions
from sendgrid.helpers.mail import Mail
from sendgrid import SendGridAPIClient
from ..database.mycosmosdb import callConnect
from ..configs.config import sendgrid_email, sendgrid_id, sendgrid_id2, sendgrid_id3, sendgrid_id4, sendgrid_key
from typing import List
import logging





FROM_EMAIL = sendgrid_email
TEMPLATE_ID = sendgrid_id
TEMPLATE_ID2 = sendgrid_id2
TEMPLATE_ID3 = sendgrid_id3
TEMPLATE_ID4 = sendgrid_id4
SENDGRID_API_KEY = sendgrid_key



class CMets(BaseModel):
    oid: str
    email: str
class DiversityMeasure(BaseModel):
    oid: str
    email: str
    metric: str
    s1: float
    s2: float
    s3: float
    s4: float
    s5: float
    s6: float
    s7: float
    s8: float
    s9: float
    s10: float
    s11: float
    s12: float
    s13: float
    s14: float
    s15: float
    s16: float
    s17: float
    s18: float
    s19: float
    s20: float
    s21: float
    s22: float
    s23: float
    s24: float
    s25: str
    s26: str
    s27: str

class DiversityMeasureFrog(BaseModel):
    oid: str
    email: str
    metric: str
    s1: float
    s2: float
    s3: float
    s4: float
    s5: float
    s6: float
    s7: float
    s8: float
    s9: float
    s10: float
    s11: float
    s12: float
    s13: float
    s14: float
    s15: float
    s16: float
    s17: float
    s18: float
    s19: float
    s20: float
    s21: float
    s22: float
    s23: float
    s24: float
    s25: str
    s26: str
    s27: str
    s28: float
    s29: float
    s30: float
    s31: float
    s32: float
    s33: float
    s34: float
    s35: float
class DivMeasure(BaseModel):
    oid: str
    email: str
    metric: str
    m1: bool
    m2: bool
    m3: bool
    m4: bool
    m5: bool
    m6: bool
    m7: bool
    s1: str
    s2: str
    s3: str
    s4: str
    s5: str
class SurveyMeasure(BaseModel):
    oid: str
    email: str
    metric: str
    label: str
    s1: str
    s2: str
    s3: str
    s4: bool
class SubmitSurvey(BaseModel):
    label: str
    metric: str
    email: str
    nano: str
    m1: bool
    m2: bool
    m3: bool
    m4: bool
    m5: bool
    m6: bool
    m7: bool
    m8: bool
    m9: bool
    s1: str
    s2: str
    s3: str
class SendSurvey(BaseModel):
    label: str
    emails: List[str]
    metric: str
    codes: List[str]
    companyName: str
class GetSurvey(BaseModel):
    label: str


def read_item(container, doc_id, account_number):
    # We can do an efficient point read lookup on partition key and id
    response = container.read_item(item=doc_id, partition_key=account_number)
    return response


diversityroute = APIRouter()



"""
Endpoint used to grab all of the diversity measure pages in the DB
"""
@diversityroute.post('/getdiversitymeasure')
async def get_diversity_measure(dmet: CMets):
    try:
        db_result = read_item(callConnect.container8, dmet.oid, dmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /getdiversitymeasure container8')
        return {"url": "/", "atype": False}
    

    if "diversitymeasure" in db_result:
        return {"dmets": db_result["diversitymeasure"]}



"""
Endpoint used to update the diversity metrics.
"""
@diversityroute.post('/diversitymeasure')
async def diversity_measure(dmet: DiversityMeasure):
    try:
        db_result = read_item(callConnect.container8, dmet.oid, dmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /diversitymeasure container8')
        return {"url": "/", "atype": False}


    if "diversitymeasure" in db_result:
        if dmet.metric == "genderRep":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "diversitymeasure": []
            }
            try:
                db_resultC = read_item(callConnect.container7, dmet.oid, dmet.email)
            except exceptions.CosmosHttpResponseError as e:
                logging.error('This is an error message for /diversitymeasure')
                return {"url": "/", "atype": False}

            if "carbonmeasure" in db_resultC:
                user2C = {
                    "id": db_resultC["id"],
                    "email": db_resultC["email"],
                    "carbonmeasure": []
                }
                mets2C = [z for z in db_resultC["carbonmeasure"] if z["label"] != "Emissions"]
                
                if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                    emData = [z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"][0]

                    if ([a for a in emData["metrics"] if a["label"] == dmet.s26]):
                        yearData2C = [aa for aa in emData["metrics"] if aa["label"] == dmet.s26][0]
                        if ([bb for bb in yearData2C["value"] if bb["label"] == dmet.s27]):
                            pass
                        else:
                            quarterData2C = [bb for bb in yearData2C["value"] if bb["label"] != dmet.s27]
                            cmeas2C = []
                            cmeas2C.append({
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            })
                            tmeas2C = [a for a in emData["metrics"] if a["label"] != dmet.s26]
                            quarterData2C.append({
                                "label": dmet.s27,
                                "metrics": [
                                    {
                                        "label": "1",
                                        "value": cmeas2C
                                    }
                                ]
                            })
                            tmeas2C.append({
                                "label": dmet.s26,
                                "value": quarterData2C
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)
                    else:
                        cmeas2C = [{
                            "scope1": 0,
                            "scope2": 0,
                            "scope3": 0
                        }]
                        tmeas2C = [a for a in emData["metrics"] if a["label"] != dmet.s26]
                        tmeas2C.append({
                                    "label": dmet.s26,
                                    "value": [
                                        {
                                            "label": dmet.s27,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value": cmeas2C
                                                }
                                            ]
                                        }
                                    ]
                                })
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": tmeas2C
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)
                
                else:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"] if z["label"] != "Emissions"]
                    newMet2C = {
                        "label": "Emissions",
                        "metrics": [
                            {
                                "label": dmet.s26,
                                "value": [
                                    {
                                        "label": dmet.s27,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "scope1": 0,
                                                            "scope2": 0,
                                                            "scope3": 0
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets2C.append(newMet2C)
                    target2C = {
                        "carbonmeasure": mets2C
                    }
                    user2C.update(target2C)
                    callConnect.container7.upsert_item(body=user2C)
        
            # call carbon emissions, if we have a same yr/qr then pass else submit scope1,2 and 0 credits
            mets = [z for z in db_result["diversitymeasure"] if z["label"] != "genderRep"]
            if ([z for z in db_result["diversitymeasure"] if z["label"] == "genderRep"]):
                genderData = [z for z in db_result["diversitymeasure"] if z["label"] == "genderRep"][0]

                if ([a for a in genderData["metrics"] if a["label"] == dmet.s26]):
                    yearData = [aa for aa in genderData["metrics"] if aa["label"] == dmet.s26][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != dmet.s27]
                    cmeas = [{
                        "maleCSuite": dmet.s1,
                        "femaleCSuite": dmet.s2,
                        "genderCSuite": dmet.s3,
                        "transCSuite": dmet.s4,
                        "preferCSuite": dmet.s5,
                        "maleEmployees": dmet.s6,
                        "femaleEmployees": dmet.s7,
                        "genderEmployees": dmet.s8,
                        "transEmployees": dmet.s9,
                        "preferEmployees": dmet.s10,
                        "maleBoard": dmet.s11,
                        "femaleBoard": dmet.s12,
                        "genderBoard": dmet.s13,
                        "transBoard": dmet.s14,
                        "preferBoard": dmet.s15
                    }]
                    tmeas = [a for a in genderData["metrics"] if a["label"] != dmet.s26]
                    quarterData.append({
                        "label": dmet.s27,
                        "value": cmeas
                    })
                    tmeas.append({
                                "label": dmet.s26,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "genderRep",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "diversitymeasure": mets
                    }
                    user.update(target)
                    callConnect.container8.upsert_item(body=user)
                else:
                    cmeas = [{
                        "maleCSuite": dmet.s1,
                        "femaleCSuite": dmet.s2,
                        "genderCSuite": dmet.s3,
                        "transCSuite": dmet.s4,
                        "preferCSuite": dmet.s5,
                        "maleEmployees": dmet.s6,
                        "femaleEmployees": dmet.s7,
                        "genderEmployees": dmet.s8,
                        "transEmployees": dmet.s9,
                        "preferEmployees": dmet.s10,
                        "maleBoard": dmet.s11,
                        "femaleBoard": dmet.s12,
                        "genderBoard": dmet.s13,
                        "transBoard": dmet.s14,
                        "preferBoard": dmet.s15
                    }]
                    tmeas = [a for a in genderData["metrics"] if a["label"] != dmet.s26]
                    tmeas.append({
                                "label": dmet.s26,
                                "value": [
                                    {
                                        "label": dmet.s27,
                                        "value": cmeas
                                    }
                                ]
                            })
                    newMet = {
                        "label": "genderRep",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "diversitymeasure": mets
                    }
                    user.update(target)
                    callConnect.container8.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "diversitymeasure": []
                }
                mets = [z for z in db_result["diversitymeasure"] if z["label"] != "genderRep"]
                newMet = {
                    "label": "genderRep",
                    "metrics": [
                        {
                            "label": dmet.s26,
                            "value": [
                                {
                                "label": dmet.s27,
                                "value": [
                                    {
                                    "maleCSuite": dmet.s1,
                                    "femaleCSuite": dmet.s2,
                                    "genderCSuite": dmet.s3,
                                    "transCSuite": dmet.s4,
                                    "preferCSuite": dmet.s5,
                                    "maleEmployees": dmet.s6,
                                    "femaleEmployees": dmet.s7,
                                    "genderEmployees": dmet.s8,
                                    "transEmployees": dmet.s9,
                                    "preferEmployees": dmet.s10,
                                    "maleBoard": dmet.s11,
                                    "femaleBoard": dmet.s12,
                                    "genderBoard": dmet.s13,
                                    "transBoard": dmet.s14,
                                    "preferBoard": dmet.s15
                                }
                                ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                newMetS = {
                    "label": "sexRep",
                    "metrics": [
                        {
                            "label": dmet.s26,
                            "value": [
                                {
                                    "label": dmet.s27,
                                    "value": [
                                        {
                                            "heteroCSuite": 0,
                                            "homoCSuite": 0,
                                            "biCSuite": 0,
                                            "preferCSuite": 0,
                                            "heteroEmployees": 0,
                                            "homoEmployees": 0,
                                            "biEmployees": 0,
                                            "preferEmployees": 0,
                                            "heteroBoard": 0,
                                            "homoBoard": 0,
                                            "biBoard": 0,
                                            "preferBoard": 0
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMetS)
                newMetR = {
                    "label": "raceRep",
                    "metrics": [
                        {
                            "label": dmet.s26,
                            "value": [
                                {
                                    "label": dmet.s27,
                                    "value": [
                                        {
                                            "asianCSuite": 0,
                                            "hawaiianCSuite": 0,
                                            "blackCSuite": 0,
                                            "hispanicCSuite": 0,
                                            "nativeCSuite": 0,
                                            "whiteCSuite": 0,
                                            "multiCSuite": 0,
                                            "preferCSuite": 0,
                                            "asianEmployees": 0,
                                            "hawaiianEmployees": 0,
                                            "blackEmployees": 0,
                                            "hispanicEmployees": 0,
                                            "nativeEmployees": 0,
                                            "whiteEmployees": 0,
                                            "multiEmployees": 0,
                                            "preferEmployees": 0,
                                            "asianBoard": 0,
                                            "hawaiianBoard": 0,
                                            "blackBoard": 0,
                                            "hispanicBoard": 0,
                                            "nativeBoard": 0,
                                            "whiteBoard": 0,
                                            "multiBoard": 0,
                                            "preferBoard": 0
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMetR)
                target = {
                    "diversitymeasure": mets
                }
                user.update(target)
                callConnect.container8.upsert_item(body=user)
        if dmet.metric == "sexRep":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "diversitymeasure": []
            }
            mets = [z for z in db_result["diversitymeasure"] if z["label"] != "sexRep"]
            if ([z for z in db_result["diversitymeasure"] if z["label"] == "sexRep"]):
                sexData = [z for z in db_result["diversitymeasure"] if z["label"] == "sexRep"][0]
                if ([a for a in sexData["metrics"] if a["label"] == dmet.s26]):
                    yearData = [aa for aa in sexData["metrics"] if aa["label"] == dmet.s26][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != dmet.s27]
                    cmeas = [{
                        "heteroCSuite": dmet.s1,
                        "homoCSuite": dmet.s2,
                        "biCSuite": dmet.s3,
                        "preferCSuite": dmet.s4,
                        "heteroEmployees": dmet.s5,
                        "homoEmployees": dmet.s6,
                        "biEmployees": dmet.s7,
                        "preferEmployees": dmet.s8,
                        "heteroBoard": dmet.s9,
                        "homoBoard": dmet.s10,
                        "biBoard": dmet.s11,
                        "preferBoard": dmet.s12
                    }]
                    tmeas = [a for a in sexData["metrics"] if a["label"] != dmet.s26]
                    quarterData.append({
                        "label": dmet.s27,
                        "value": cmeas
                    })
                    tmeas.append({
                                "label": dmet.s26,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "sexRep",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "diversitymeasure": mets
                    }
                    user.update(target)
                    callConnect.container8.upsert_item(body=user)
                else:
                    cmeas = [{
                        "heteroCSuite": dmet.s1,
                        "homoCSuite": dmet.s2,
                        "biCSuite": dmet.s3,
                        "preferCSuite": dmet.s4,
                        "heteroEmployees": dmet.s5,
                        "homoEmployees": dmet.s6,
                        "biEmployees": dmet.s7,
                        "preferEmployees": dmet.s8,
                        "heteroBoard": dmet.s9,
                        "homoBoard": dmet.s10,
                        "biBoard": dmet.s11,
                        "preferBoard": dmet.s12
                    }]
                    tmeas = [a for a in sexData["metrics"] if a["label"] != dmet.s26]
                    tmeas.append({
                                "label": dmet.s26,
                                "value": [
                                    {
                                        "label": dmet.s27,
                                        "value": cmeas
                                    }
                                ]
                            })
                    newMet = {
                        "label": "sexRep",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "diversitymeasure": mets
                    }
                    user.update(target)
                    callConnect.container8.upsert_item(body=user)
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "diversitymeasure": []
                }
                mets = [z for z in db_result["diversitymeasure"] if z["label"] != "sexRep"]
                newMet = {
                    "label": "sexRep",
                    "metrics": [
                        {
                            "label": dmet.s26,
                            "value": [
                                {
                                    "label": dmet.s27,
                                    "value": [
                                        {
                                            "heteroCSuite": dmet.s1,
                                            "homoCSuite": dmet.s2,
                                            "biCSuite": dmet.s3,
                                            "preferCSuite": dmet.s4,
                                            "heteroEmployees": dmet.s5,
                                            "homoEmployees": dmet.s6,
                                            "biEmployees": dmet.s7,
                                            "preferEmployees": dmet.s8,
                                            "heteroBoard": dmet.s9,
                                            "homoBoard": dmet.s10,
                                            "biBoard": dmet.s11,
                                            "preferBoard": dmet.s12
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "diversitymeasure": mets
                }
                user.update(target)
                callConnect.container8.upsert_item(body=user)
        if dmet.metric == "raceRep":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "diversitymeasure": []
            }
            mets = [z for z in db_result["diversitymeasure"] if z["label"] != "raceRep"]
            if ([z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"]):
                raceData = [z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"][0]

                if ([a for a in raceData["metrics"] if a["label"] == dmet.s26]):
                    yearData = [aa for aa in raceData["metrics"] if aa["label"] == dmet.s26][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != dmet.s27]
                    cmeas = [{
                        "asianCSuite": dmet.s1,
                        "hawaiianCSuite": dmet.s2,
                        "blackCSuite": dmet.s3,
                        "hispanicCSuite": dmet.s4,
                        "nativeCSuite": dmet.s5,
                        "whiteCSuite": dmet.s6,
                        "multiCSuite": dmet.s7,
                        "preferCSuite": dmet.s8,
                        "asianEmployees": dmet.s9,
                        "hawaiianEmployees": dmet.s10,
                        "blackEmployees": dmet.s11,
                        "hispanicEmployees": dmet.s12,
                        "nativeEmployees": dmet.s13,
                        "whiteEmployees": dmet.s14,
                        "multiEmployees": dmet.s15,
                        "preferEmployees": dmet.s16,
                        "asianBoard": dmet.s17,
                        "hawaiianBoard": dmet.s18,
                        "blackBoard": dmet.s19,
                        "hispanicBoard": dmet.s20,
                        "nativeBoard": dmet.s21,
                        "whiteBoard": dmet.s22,
                        "multiBoard": dmet.s23,
                        "preferBoard": dmet.s24
                    }]
                    tmeas = [a for a in raceData["metrics"] if a["label"] != dmet.s26]
                    quarterData.append({
                        "label": dmet.s27,
                        "value": cmeas
                    })
                    tmeas.append({
                                "label": dmet.s26,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "raceRep",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "diversitymeasure": mets
                    }
                    user.update(target)
                    callConnect.container8.upsert_item(body=user)
                else:
                    cmeas = [{
                        "asianCSuite": dmet.s1,
                        "hawaiianCSuite": dmet.s2,
                        "blackCSuite": dmet.s3,
                        "hispanicCSuite": dmet.s4,
                        "nativeCSuite": dmet.s5,
                        "whiteCSuite": dmet.s6,
                        "multiCSuite": dmet.s7,
                        "preferCSuite": dmet.s8,
                        "asianEmployees": dmet.s9,
                        "hawaiianEmployees": dmet.s10,
                        "blackEmployees": dmet.s11,
                        "hispanicEmployees": dmet.s12,
                        "nativeEmployees": dmet.s13,
                        "whiteEmployees": dmet.s14,
                        "multiEmployees": dmet.s15,
                        "preferEmployees": dmet.s16,
                        "asianBoard": dmet.s17,
                        "hawaiianBoard": dmet.s18,
                        "blackBoard": dmet.s19,
                        "hispanicBoard": dmet.s20,
                        "nativeBoard": dmet.s21,
                        "whiteBoard": dmet.s22,
                        "multiBoard": dmet.s23,
                        "preferBoard": dmet.s24
                    }]
                    tmeas = [a for a in raceData["metrics"] if a["label"] != dmet.s26]
                    tmeas.append({
                                "label": dmet.s26,
                                "value": [
                                    {
                                        "label": dmet.s27,
                                        "value": cmeas
                                    }
                                ]
                            })
                    newMet = {
                        "label": "raceRep",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "diversitymeasure": mets
                    }
                    user.update(target)
                    callConnect.container8.upsert_item(body=user)
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "diversitymeasure": []
                }
                mets = [z for z in db_result["diversitymeasure"] if z["label"] != "raceRep"]
                newMet = {
                    "label": "raceRep",
                    "metrics": [
                        {
                            "label": dmet.s26,
                            "value": [
                                {
                                    "label": dmet.s27,
                                    "value": [
                                        {
                                            "asianCSuite": dmet.s1,
                                            "hawaiianCSuite": dmet.s2,
                                            "blackCSuite": dmet.s3,
                                            "hispanicCSuite": dmet.s4,
                                            "nativeCSuite": dmet.s5,
                                            "whiteCSuite": dmet.s6,
                                            "multiCSuite": dmet.s7,
                                            "preferCSuite": dmet.s8,
                                            "asianEmployees": dmet.s9,
                                            "hawaiianEmployees": dmet.s10,
                                            "blackEmployees": dmet.s11,
                                            "hispanicEmployees": dmet.s12,
                                            "nativeEmployees": dmet.s13,
                                            "whiteEmployees": dmet.s14,
                                            "multiEmployees": dmet.s15,
                                            "preferEmployees": dmet.s16,
                                            "asianBoard": dmet.s17,
                                            "hawaiianBoard": dmet.s18,
                                            "blackBoard": dmet.s19,
                                            "hispanicBoard": dmet.s20,
                                            "nativeBoard": dmet.s21,
                                            "whiteBoard": dmet.s22,
                                            "multiBoard": dmet.s23,
                                            "preferBoard": dmet.s24
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "diversitymeasure": mets
                }
                user.update(target)
                callConnect.container8.upsert_item(body=user)
        if dmet.metric == "SurveyCode":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "diversitymeasure": []
            }

            try:
                db_resultC = read_item(callConnect.container7, dmet.oid, dmet.email)
            except exceptions.CosmosHttpResponseError as e:
                logging.error('This is an error message for /diversitymeasure')
                return {"url": "/", "atype": False}

            if "carbonmeasure" in db_resultC:
                user2C = {
                    "id": db_resultC["id"],
                    "email": db_resultC["email"],
                    "carbonmeasure": []
                }
                mets2C = [z for z in db_resultC["carbonmeasure"] if z["label"] != "Emissions"]
                
                if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                    emData = [z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"][0]

                    if ([a for a in emData["metrics"] if a["label"] == dmet.s26]):
                        yearData2C = [aa for aa in emData["metrics"] if aa["label"] == dmet.s26][0]
                        if ([bb for bb in yearData2C["value"] if bb["label"] == dmet.s27]):
                            pass
                        else:
                            quarterData2C = [bb for bb in yearData2C["value"] if bb["label"] != dmet.s27]
                            cmeas2C = []
                            cmeas2C.append({
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            })
                            tmeas2C = [a for a in emData["metrics"] if a["label"] != dmet.s26]
                            quarterData2C.append({
                                "label": dmet.s27,
                                "metrics": [
                                    {
                                        "label": "1",
                                        "value": cmeas2C
                                    }
                                ]
                            })
                            tmeas2C.append({
                                "label": dmet.s26,
                                "value": quarterData2C
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)
                    else:
                        cmeas2C = [{
                            "scope1": 0,
                            "scope2": 0,
                            "scope3": 0
                        }]
                        tmeas2C = [a for a in emData["metrics"] if a["label"] != dmet.s26]
                        tmeas2C.append({
                                    "label": dmet.s26,
                                    "value": [
                                        {
                                            "label": dmet.s27,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value": cmeas2C
                                                }
                                            ]
                                        }
                                    ]
                                })
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": tmeas2C
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)
                
                else:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"] if z["label"] != "Emissions"]
                    newMet2C = {
                        "label": "Emissions",
                        "metrics": [
                            {
                                "label": dmet.s26,
                                "value": [
                                    {
                                        "label": dmet.s27,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "scope1": 0,
                                                            "scope2": 0,
                                                            "scope3": 0
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets2C.append(newMet2C)
                    target2C = {
                        "carbonmeasure": mets2C
                    }
                    user2C.update(target2C)
                    callConnect.container7.upsert_item(body=user2C)

            mets = [z for z in db_result["diversitymeasure"] if z["label"] != "SurveyCode"]
            if ([z for z in db_result["diversitymeasure"] if z["label"] == "SurveyCode"]):
                surveyData = [z for z in db_result["diversitymeasure"] if z["label"] == "SurveyCode"][0]

                if ([a for a in surveyData["metrics"] if a["label"] == dmet.s26]):
                    yearData = [aa for aa in surveyData["metrics"] if aa["label"] == dmet.s26][0]
                    if ([bb for bb in yearData["value"] if bb["label"] == dmet.s27]):
                        pass
                    else:
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != dmet.s27]
                        cmeas = [{
                            "code": dmet.s25
                        }]
                        tmeas = [a for a in surveyData["metrics"] if a["label"] != dmet.s26]
                        quarterData.append({
                            "label": dmet.s27,
                            "value": cmeas
                        })
                        tmeas.append({
                                    "label": dmet.s26,
                                    "value": quarterData
                                })
                        newMet = {
                            "label": "SurveyCode",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "diversitymeasure": mets
                        }
                        user.update(target)
                        callConnect.container8.upsert_item(body=user)
                        user2 = {
                            "id": dmet.s25,
                            "surveymeasure": []
                        }
                        callConnect.container9.upsert_item(body=user2)
                else:
                    cmeas = [{
                        "code": dmet.s25
                    }]
                    tmeas = [a for a in surveyData["metrics"] if a["label"] != dmet.s26]
                    tmeas.append({
                                "label": dmet.s26,
                                "value": [
                                    {
                                        "label": dmet.s27,
                                        "value": cmeas
                                    }
                                ]
                            })
                    newMet = {
                        "label": "SurveyCode",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "diversitymeasure": mets
                    }
                    user.update(target)
                    callConnect.container8.upsert_item(body=user)
                    user2 = {
                        "id": dmet.s25,
                        "surveymeasure": []
                    }
                    callConnect.container9.upsert_item(body=user2)
            else:
                cmeas = [{
                    "code": dmet.s25
                }]
                tmeas = []
                tmeas.append({
                            "label": dmet.s26,
                            "value": [
                                {
                                    "label": dmet.s27,
                                    "value": cmeas
                                }
                            ]
                        })
                newMet = {
                    "label": "SurveyCode",
                    "metrics": tmeas
                }
                mets.append(newMet)

                if ([z for z in db_result["diversitymeasure"] if z["label"] == "genderRep"]):
                    genderData = [z for z in db_result["diversitymeasure"] if z["label"] == "genderRep"][0]
                    if ([a for a in genderData["metrics"] if a["label"] == dmet.s26]):
                        yearData = [aa for aa in genderData["metrics"] if aa["label"] == dmet.s26][0]
                        if ([bb for bb in yearData["value"] if bb["label"] == dmet.s27]):
                            # check sex n race
                            if ([z for z in db_result["diversitymeasure"] if z["label"] == "sexRep"]):
                                sexData = [z for z in db_result["diversitymeasure"] if z["label"] == "sexRep"][0]
                                if ([a for a in sexData["metrics"] if a["label"] == dmet.s26]):
                                    yearDataS = [aa for aa in sexData["metrics"] if aa["label"] == dmet.s26][0]
                                    if ([bb for bb in yearDataS["value"] if bb["label"] == dmet.s27]):
                                        if ([z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"]):
                                            raceData = [z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"][0]
                                            if ([a for a in raceData["metrics"] if a["label"] == dmet.s26]):
                                                yearDataR = [aa for aa in raceData["metrics"] if aa["label"] == dmet.s26][0]
                                                if ([bb for bb in yearDataR["value"] if bb["label"] == dmet.s27]):
                                                    pass
                                                else:
                                                    newMetR = {
                                                        "label": "raceRep",
                                                        "metrics": [
                                                            {
                                                                "label": dmet.s26,
                                                                "value": [
                                                                    {
                                                                        "label": dmet.s27,
                                                                        "value": [
                                                                            {
                                                                                "asianCSuite": 0,
                                                                                "hawaiianCSuite": 0,
                                                                                "blackCSuite": 0,
                                                                                "hispanicCSuite": 0,
                                                                                "nativeCSuite": 0,
                                                                                "whiteCSuite": 0,
                                                                                "multiCSuite": 0,
                                                                                "preferCSuite": 0,
                                                                                "asianEmployees": 0,
                                                                                "hawaiianEmployees": 0,
                                                                                "blackEmployees": 0,
                                                                                "hispanicEmployees": 0,
                                                                                "nativeEmployees": 0,
                                                                                "whiteEmployees": 0,
                                                                                "multiEmployees": 0,
                                                                                "preferEmployees": 0,
                                                                                "asianBoard": 0,
                                                                                "hawaiianBoard": 0,
                                                                                "blackBoard": 0,
                                                                                "hispanicBoard": 0,
                                                                                "nativeBoard": 0,
                                                                                "whiteBoard": 0,
                                                                                "multiBoard": 0,
                                                                                "preferBoard": 0
                                                                            }
                                                                        ]
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                    mets.append(newMetR)
                                            else:
                                                newMetR = {
                                                    "label": "raceRep",
                                                    "metrics": [
                                                        {
                                                            "label": dmet.s26,
                                                            "value": [
                                                                {
                                                                    "label": dmet.s27,
                                                                    "value": [
                                                                        {
                                                                            "asianCSuite": 0,
                                                                            "hawaiianCSuite": 0,
                                                                            "blackCSuite": 0,
                                                                            "hispanicCSuite": 0,
                                                                            "nativeCSuite": 0,
                                                                            "whiteCSuite": 0,
                                                                            "multiCSuite": 0,
                                                                            "preferCSuite": 0,
                                                                            "asianEmployees": 0,
                                                                            "hawaiianEmployees": 0,
                                                                            "blackEmployees": 0,
                                                                            "hispanicEmployees": 0,
                                                                            "nativeEmployees": 0,
                                                                            "whiteEmployees": 0,
                                                                            "multiEmployees": 0,
                                                                            "preferEmployees": 0,
                                                                            "asianBoard": 0,
                                                                            "hawaiianBoard": 0,
                                                                            "blackBoard": 0,
                                                                            "hispanicBoard": 0,
                                                                            "nativeBoard": 0,
                                                                            "whiteBoard": 0,
                                                                            "multiBoard": 0,
                                                                            "preferBoard": 0
                                                                        }
                                                                    ]
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                                mets.append(newMetR)
                                        else:
                                            newMetR = {
                                                "label": "raceRep",
                                                "metrics": [
                                                    {
                                                        "label": dmet.s26,
                                                        "value": [
                                                            {
                                                                "label": dmet.s27,
                                                                "value": [
                                                                    {
                                                                        "asianCSuite": 0,
                                                                        "hawaiianCSuite": 0,
                                                                        "blackCSuite": 0,
                                                                        "hispanicCSuite": 0,
                                                                        "nativeCSuite": 0,
                                                                        "whiteCSuite": 0,
                                                                        "multiCSuite": 0,
                                                                        "preferCSuite": 0,
                                                                        "asianEmployees": 0,
                                                                        "hawaiianEmployees": 0,
                                                                        "blackEmployees": 0,
                                                                        "hispanicEmployees": 0,
                                                                        "nativeEmployees": 0,
                                                                        "whiteEmployees": 0,
                                                                        "multiEmployees": 0,
                                                                        "preferEmployees": 0,
                                                                        "asianBoard": 0,
                                                                        "hawaiianBoard": 0,
                                                                        "blackBoard": 0,
                                                                        "hispanicBoard": 0,
                                                                        "nativeBoard": 0,
                                                                        "whiteBoard": 0,
                                                                        "multiBoard": 0,
                                                                        "preferBoard": 0
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                            mets.append(newMetR)
                                    else:
                                        newMetS = {
                                            "label": "sexRep",
                                            "metrics": [
                                                {
                                                    "label": dmet.s26,
                                                    "value": [
                                                        {
                                                            "label": dmet.s27,
                                                            "value": [
                                                                {
                                                                    "heteroCSuite": 0,
                                                                    "homoCSuite": 0,
                                                                    "biCSuite": 0,
                                                                    "preferCSuite": 0,
                                                                    "heteroEmployees": 0,
                                                                    "homoEmployees": 0,
                                                                    "biEmployees": 0,
                                                                    "preferEmployees": 0,
                                                                    "heteroBoard": 0,
                                                                    "homoBoard": 0,
                                                                    "biBoard": 0,
                                                                    "preferBoard": 0
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                        mets.append(newMetS)
                                        if ([z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"]):
                                            raceData = [z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"][0]
                                            if ([a for a in raceData["metrics"] if a["label"] == dmet.s26]):
                                                yearDataR = [aa for aa in raceData["metrics"] if aa["label"] == dmet.s26][0]
                                                if ([bb for bb in yearDataR["value"] if bb["label"] == dmet.s27]):
                                                    pass
                                                else:
                                                    newMetR = {
                                                        "label": "raceRep",
                                                        "metrics": [
                                                            {
                                                                "label": dmet.s26,
                                                                "value": [
                                                                    {
                                                                        "label": dmet.s27,
                                                                        "value": [
                                                                            {
                                                                                "asianCSuite": 0,
                                                                                "hawaiianCSuite": 0,
                                                                                "blackCSuite": 0,
                                                                                "hispanicCSuite": 0,
                                                                                "nativeCSuite": 0,
                                                                                "whiteCSuite": 0,
                                                                                "multiCSuite": 0,
                                                                                "preferCSuite": 0,
                                                                                "asianEmployees": 0,
                                                                                "hawaiianEmployees": 0,
                                                                                "blackEmployees": 0,
                                                                                "hispanicEmployees": 0,
                                                                                "nativeEmployees": 0,
                                                                                "whiteEmployees": 0,
                                                                                "multiEmployees": 0,
                                                                                "preferEmployees": 0,
                                                                                "asianBoard": 0,
                                                                                "hawaiianBoard": 0,
                                                                                "blackBoard": 0,
                                                                                "hispanicBoard": 0,
                                                                                "nativeBoard": 0,
                                                                                "whiteBoard": 0,
                                                                                "multiBoard": 0,
                                                                                "preferBoard": 0
                                                                            }
                                                                        ]
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                    mets.append(newMetR)
                                            else:
                                                newMetR = {
                                                    "label": "raceRep",
                                                    "metrics": [
                                                        {
                                                            "label": dmet.s26,
                                                            "value": [
                                                                {
                                                                    "label": dmet.s27,
                                                                    "value": [
                                                                        {
                                                                            "asianCSuite": 0,
                                                                            "hawaiianCSuite": 0,
                                                                            "blackCSuite": 0,
                                                                            "hispanicCSuite": 0,
                                                                            "nativeCSuite": 0,
                                                                            "whiteCSuite": 0,
                                                                            "multiCSuite": 0,
                                                                            "preferCSuite": 0,
                                                                            "asianEmployees": 0,
                                                                            "hawaiianEmployees": 0,
                                                                            "blackEmployees": 0,
                                                                            "hispanicEmployees": 0,
                                                                            "nativeEmployees": 0,
                                                                            "whiteEmployees": 0,
                                                                            "multiEmployees": 0,
                                                                            "preferEmployees": 0,
                                                                            "asianBoard": 0,
                                                                            "hawaiianBoard": 0,
                                                                            "blackBoard": 0,
                                                                            "hispanicBoard": 0,
                                                                            "nativeBoard": 0,
                                                                            "whiteBoard": 0,
                                                                            "multiBoard": 0,
                                                                            "preferBoard": 0
                                                                        }
                                                                    ]
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                                mets.append(newMetR)
                                        else:
                                            newMetR = {
                                                "label": "raceRep",
                                                "metrics": [
                                                    {
                                                        "label": dmet.s26,
                                                        "value": [
                                                            {
                                                                "label": dmet.s27,
                                                                "value": [
                                                                    {
                                                                        "asianCSuite": 0,
                                                                        "hawaiianCSuite": 0,
                                                                        "blackCSuite": 0,
                                                                        "hispanicCSuite": 0,
                                                                        "nativeCSuite": 0,
                                                                        "whiteCSuite": 0,
                                                                        "multiCSuite": 0,
                                                                        "preferCSuite": 0,
                                                                        "asianEmployees": 0,
                                                                        "hawaiianEmployees": 0,
                                                                        "blackEmployees": 0,
                                                                        "hispanicEmployees": 0,
                                                                        "nativeEmployees": 0,
                                                                        "whiteEmployees": 0,
                                                                        "multiEmployees": 0,
                                                                        "preferEmployees": 0,
                                                                        "asianBoard": 0,
                                                                        "hawaiianBoard": 0,
                                                                        "blackBoard": 0,
                                                                        "hispanicBoard": 0,
                                                                        "nativeBoard": 0,
                                                                        "whiteBoard": 0,
                                                                        "multiBoard": 0,
                                                                        "preferBoard": 0
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                            mets.append(newMetR)

                                else:
                                    newMetS = {
                                            "label": "sexRep",
                                            "metrics": [
                                                {
                                                    "label": dmet.s26,
                                                    "value": [
                                                        {
                                                            "label": dmet.s27,
                                                            "value": [
                                                                {
                                                                    "heteroCSuite": 0,
                                                                    "homoCSuite": 0,
                                                                    "biCSuite": 0,
                                                                    "preferCSuite": 0,
                                                                    "heteroEmployees": 0,
                                                                    "homoEmployees": 0,
                                                                    "biEmployees": 0,
                                                                    "preferEmployees": 0,
                                                                    "heteroBoard": 0,
                                                                    "homoBoard": 0,
                                                                    "biBoard": 0,
                                                                    "preferBoard": 0
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                    mets.append(newMetS)
                                    if ([z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"]):
                                        raceData = [z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"][0]
                                        if ([a for a in raceData["metrics"] if a["label"] == dmet.s26]):
                                            yearDataR = [aa for aa in raceData["metrics"] if aa["label"] == dmet.s26][0]
                                            if ([bb for bb in yearDataR["value"] if bb["label"] == dmet.s27]):
                                                pass
                                            else:
                                                newMetR = {
                                                    "label": "raceRep",
                                                    "metrics": [
                                                        {
                                                            "label": dmet.s26,
                                                            "value": [
                                                                {
                                                                    "label": dmet.s27,
                                                                    "value": [
                                                                        {
                                                                            "asianCSuite": 0,
                                                                            "hawaiianCSuite": 0,
                                                                            "blackCSuite": 0,
                                                                            "hispanicCSuite": 0,
                                                                            "nativeCSuite": 0,
                                                                            "whiteCSuite": 0,
                                                                            "multiCSuite": 0,
                                                                            "preferCSuite": 0,
                                                                            "asianEmployees": 0,
                                                                            "hawaiianEmployees": 0,
                                                                            "blackEmployees": 0,
                                                                            "hispanicEmployees": 0,
                                                                            "nativeEmployees": 0,
                                                                            "whiteEmployees": 0,
                                                                            "multiEmployees": 0,
                                                                            "preferEmployees": 0,
                                                                            "asianBoard": 0,
                                                                            "hawaiianBoard": 0,
                                                                            "blackBoard": 0,
                                                                            "hispanicBoard": 0,
                                                                            "nativeBoard": 0,
                                                                            "whiteBoard": 0,
                                                                            "multiBoard": 0,
                                                                            "preferBoard": 0
                                                                        }
                                                                    ]
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                                mets.append(newMetR)
                                        else:
                                            newMetR = {
                                                "label": "raceRep",
                                                "metrics": [
                                                    {
                                                        "label": dmet.s26,
                                                        "value": [
                                                            {
                                                                "label": dmet.s27,
                                                                "value": [
                                                                    {
                                                                        "asianCSuite": 0,
                                                                        "hawaiianCSuite": 0,
                                                                        "blackCSuite": 0,
                                                                        "hispanicCSuite": 0,
                                                                        "nativeCSuite": 0,
                                                                        "whiteCSuite": 0,
                                                                        "multiCSuite": 0,
                                                                        "preferCSuite": 0,
                                                                        "asianEmployees": 0,
                                                                        "hawaiianEmployees": 0,
                                                                        "blackEmployees": 0,
                                                                        "hispanicEmployees": 0,
                                                                        "nativeEmployees": 0,
                                                                        "whiteEmployees": 0,
                                                                        "multiEmployees": 0,
                                                                        "preferEmployees": 0,
                                                                        "asianBoard": 0,
                                                                        "hawaiianBoard": 0,
                                                                        "blackBoard": 0,
                                                                        "hispanicBoard": 0,
                                                                        "nativeBoard": 0,
                                                                        "whiteBoard": 0,
                                                                        "multiBoard": 0,
                                                                        "preferBoard": 0
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                            mets.append(newMetR)
                                    else:
                                        newMetR = {
                                            "label": "raceRep",
                                            "metrics": [
                                                {
                                                    "label": dmet.s26,
                                                    "value": [
                                                        {
                                                            "label": dmet.s27,
                                                            "value": [
                                                                {
                                                                    "asianCSuite": 0,
                                                                    "hawaiianCSuite": 0,
                                                                    "blackCSuite": 0,
                                                                    "hispanicCSuite": 0,
                                                                    "nativeCSuite": 0,
                                                                    "whiteCSuite": 0,
                                                                    "multiCSuite": 0,
                                                                    "preferCSuite": 0,
                                                                    "asianEmployees": 0,
                                                                    "hawaiianEmployees": 0,
                                                                    "blackEmployees": 0,
                                                                    "hispanicEmployees": 0,
                                                                    "nativeEmployees": 0,
                                                                    "whiteEmployees": 0,
                                                                    "multiEmployees": 0,
                                                                    "preferEmployees": 0,
                                                                    "asianBoard": 0,
                                                                    "hawaiianBoard": 0,
                                                                    "blackBoard": 0,
                                                                    "hispanicBoard": 0,
                                                                    "nativeBoard": 0,
                                                                    "whiteBoard": 0,
                                                                    "multiBoard": 0,
                                                                    "preferBoard": 0
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                        mets.append(newMetR)
                            else:
                                newMetS = {
                                            "label": "sexRep",
                                            "metrics": [
                                                {
                                                    "label": dmet.s26,
                                                    "value": [
                                                        {
                                                            "label": dmet.s27,
                                                            "value": [
                                                                {
                                                                    "heteroCSuite": 0,
                                                                    "homoCSuite": 0,
                                                                    "biCSuite": 0,
                                                                    "preferCSuite": 0,
                                                                    "heteroEmployees": 0,
                                                                    "homoEmployees": 0,
                                                                    "biEmployees": 0,
                                                                    "preferEmployees": 0,
                                                                    "heteroBoard": 0,
                                                                    "homoBoard": 0,
                                                                    "biBoard": 0,
                                                                    "preferBoard": 0
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                mets.append(newMetS)
                                if ([z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"]):
                                    raceData = [z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"][0]
                                    if ([a for a in raceData["metrics"] if a["label"] == dmet.s26]):
                                        yearDataR = [aa for aa in raceData["metrics"] if aa["label"] == dmet.s26][0]
                                        if ([bb for bb in yearDataR["value"] if bb["label"] == dmet.s27]):
                                            pass
                                        else:
                                            newMetR = {
                                                "label": "raceRep",
                                                "metrics": [
                                                    {
                                                        "label": dmet.s26,
                                                        "value": [
                                                            {
                                                                "label": dmet.s27,
                                                                "value": [
                                                                    {
                                                                        "asianCSuite": 0,
                                                                        "hawaiianCSuite": 0,
                                                                        "blackCSuite": 0,
                                                                        "hispanicCSuite": 0,
                                                                        "nativeCSuite": 0,
                                                                        "whiteCSuite": 0,
                                                                        "multiCSuite": 0,
                                                                        "preferCSuite": 0,
                                                                        "asianEmployees": 0,
                                                                        "hawaiianEmployees": 0,
                                                                        "blackEmployees": 0,
                                                                        "hispanicEmployees": 0,
                                                                        "nativeEmployees": 0,
                                                                        "whiteEmployees": 0,
                                                                        "multiEmployees": 0,
                                                                        "preferEmployees": 0,
                                                                        "asianBoard": 0,
                                                                        "hawaiianBoard": 0,
                                                                        "blackBoard": 0,
                                                                        "hispanicBoard": 0,
                                                                        "nativeBoard": 0,
                                                                        "whiteBoard": 0,
                                                                        "multiBoard": 0,
                                                                        "preferBoard": 0
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                            mets.append(newMetR)
                                    else:
                                        newMetR = {
                                            "label": "raceRep",
                                            "metrics": [
                                                {
                                                    "label": dmet.s26,
                                                    "value": [
                                                        {
                                                            "label": dmet.s27,
                                                            "value": [
                                                                {
                                                                    "asianCSuite": 0,
                                                                    "hawaiianCSuite": 0,
                                                                    "blackCSuite": 0,
                                                                    "hispanicCSuite": 0,
                                                                    "nativeCSuite": 0,
                                                                    "whiteCSuite": 0,
                                                                    "multiCSuite": 0,
                                                                    "preferCSuite": 0,
                                                                    "asianEmployees": 0,
                                                                    "hawaiianEmployees": 0,
                                                                    "blackEmployees": 0,
                                                                    "hispanicEmployees": 0,
                                                                    "nativeEmployees": 0,
                                                                    "whiteEmployees": 0,
                                                                    "multiEmployees": 0,
                                                                    "preferEmployees": 0,
                                                                    "asianBoard": 0,
                                                                    "hawaiianBoard": 0,
                                                                    "blackBoard": 0,
                                                                    "hispanicBoard": 0,
                                                                    "nativeBoard": 0,
                                                                    "whiteBoard": 0,
                                                                    "multiBoard": 0,
                                                                    "preferBoard": 0
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                        mets.append(newMetR)
                                else:
                                    newMetR = {
                                        "label": "raceRep",
                                        "metrics": [
                                            {
                                                "label": dmet.s26,
                                                "value": [
                                                    {
                                                        "label": dmet.s27,
                                                        "value": [
                                                            {
                                                                "asianCSuite": 0,
                                                                "hawaiianCSuite": 0,
                                                                "blackCSuite": 0,
                                                                "hispanicCSuite": 0,
                                                                "nativeCSuite": 0,
                                                                "whiteCSuite": 0,
                                                                "multiCSuite": 0,
                                                                "preferCSuite": 0,
                                                                "asianEmployees": 0,
                                                                "hawaiianEmployees": 0,
                                                                "blackEmployees": 0,
                                                                "hispanicEmployees": 0,
                                                                "nativeEmployees": 0,
                                                                "whiteEmployees": 0,
                                                                "multiEmployees": 0,
                                                                "preferEmployees": 0,
                                                                "asianBoard": 0,
                                                                "hawaiianBoard": 0,
                                                                "blackBoard": 0,
                                                                "hispanicBoard": 0,
                                                                "nativeBoard": 0,
                                                                "whiteBoard": 0,
                                                                "multiBoard": 0,
                                                                "preferBoard": 0
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                        ]
                                    }
                                    mets.append(newMetR)
                        else:
                            newMetG = {
                            "label": "genderRep",
                            "metrics": [
                                {
                                    "label": dmet.s26,
                                    "value": [
                                        {
                                        "label": dmet.s27,
                                        "value": [
                                            {
                                            "maleCSuite": dmet.s1,
                                            "femaleCSuite": dmet.s2,
                                            "genderCSuite": dmet.s3,
                                            "transCSuite": dmet.s4,
                                            "preferCSuite": dmet.s5,
                                            "maleEmployees": dmet.s6,
                                            "femaleEmployees": dmet.s7,
                                            "genderEmployees": dmet.s8,
                                            "transEmployees": dmet.s9,
                                            "preferEmployees": dmet.s10,
                                            "maleBoard": dmet.s11,
                                            "femaleBoard": dmet.s12,
                                            "genderBoard": dmet.s13,
                                            "transBoard": dmet.s14,
                                            "preferBoard": dmet.s15
                                        }
                                        ]
                                        }
                                    ]
                                }
                            ]
                            }
                            mets.append(newMetG)
                            if ([z for z in db_result["diversitymeasure"] if z["label"] == "sexRep"]):
                                sexData = [z for z in db_result["diversitymeasure"] if z["label"] == "sexRep"][0]
                                if ([a for a in sexData["metrics"] if a["label"] == dmet.s26]):
                                    yearDataS = [aa for aa in sexData["metrics"] if aa["label"] == dmet.s26][0]
                                    if ([bb for bb in yearDataS["value"] if bb["label"] == dmet.s27]):
                                        if ([z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"]):
                                            raceData = [z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"][0]
                                            if ([a for a in raceData["metrics"] if a["label"] == dmet.s26]):
                                                yearDataR = [aa for aa in raceData["metrics"] if aa["label"] == dmet.s26][0]
                                                if ([bb for bb in yearDataR["value"] if bb["label"] == dmet.s27]):
                                                    pass
                                                else:
                                                    newMetR = {
                                                        "label": "raceRep",
                                                        "metrics": [
                                                            {
                                                                "label": dmet.s26,
                                                                "value": [
                                                                    {
                                                                        "label": dmet.s27,
                                                                        "value": [
                                                                            {
                                                                                "asianCSuite": 0,
                                                                                "hawaiianCSuite": 0,
                                                                                "blackCSuite": 0,
                                                                                "hispanicCSuite": 0,
                                                                                "nativeCSuite": 0,
                                                                                "whiteCSuite": 0,
                                                                                "multiCSuite": 0,
                                                                                "preferCSuite": 0,
                                                                                "asianEmployees": 0,
                                                                                "hawaiianEmployees": 0,
                                                                                "blackEmployees": 0,
                                                                                "hispanicEmployees": 0,
                                                                                "nativeEmployees": 0,
                                                                                "whiteEmployees": 0,
                                                                                "multiEmployees": 0,
                                                                                "preferEmployees": 0,
                                                                                "asianBoard": 0,
                                                                                "hawaiianBoard": 0,
                                                                                "blackBoard": 0,
                                                                                "hispanicBoard": 0,
                                                                                "nativeBoard": 0,
                                                                                "whiteBoard": 0,
                                                                                "multiBoard": 0,
                                                                                "preferBoard": 0
                                                                            }
                                                                        ]
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                    mets.append(newMetR)
                                            else:
                                                newMetR = {
                                                    "label": "raceRep",
                                                    "metrics": [
                                                        {
                                                            "label": dmet.s26,
                                                            "value": [
                                                                {
                                                                    "label": dmet.s27,
                                                                    "value": [
                                                                        {
                                                                            "asianCSuite": 0,
                                                                            "hawaiianCSuite": 0,
                                                                            "blackCSuite": 0,
                                                                            "hispanicCSuite": 0,
                                                                            "nativeCSuite": 0,
                                                                            "whiteCSuite": 0,
                                                                            "multiCSuite": 0,
                                                                            "preferCSuite": 0,
                                                                            "asianEmployees": 0,
                                                                            "hawaiianEmployees": 0,
                                                                            "blackEmployees": 0,
                                                                            "hispanicEmployees": 0,
                                                                            "nativeEmployees": 0,
                                                                            "whiteEmployees": 0,
                                                                            "multiEmployees": 0,
                                                                            "preferEmployees": 0,
                                                                            "asianBoard": 0,
                                                                            "hawaiianBoard": 0,
                                                                            "blackBoard": 0,
                                                                            "hispanicBoard": 0,
                                                                            "nativeBoard": 0,
                                                                            "whiteBoard": 0,
                                                                            "multiBoard": 0,
                                                                            "preferBoard": 0
                                                                        }
                                                                    ]
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                                mets.append(newMetR)
                                        else:
                                            newMetR = {
                                                "label": "raceRep",
                                                "metrics": [
                                                    {
                                                        "label": dmet.s26,
                                                        "value": [
                                                            {
                                                                "label": dmet.s27,
                                                                "value": [
                                                                    {
                                                                        "asianCSuite": 0,
                                                                        "hawaiianCSuite": 0,
                                                                        "blackCSuite": 0,
                                                                        "hispanicCSuite": 0,
                                                                        "nativeCSuite": 0,
                                                                        "whiteCSuite": 0,
                                                                        "multiCSuite": 0,
                                                                        "preferCSuite": 0,
                                                                        "asianEmployees": 0,
                                                                        "hawaiianEmployees": 0,
                                                                        "blackEmployees": 0,
                                                                        "hispanicEmployees": 0,
                                                                        "nativeEmployees": 0,
                                                                        "whiteEmployees": 0,
                                                                        "multiEmployees": 0,
                                                                        "preferEmployees": 0,
                                                                        "asianBoard": 0,
                                                                        "hawaiianBoard": 0,
                                                                        "blackBoard": 0,
                                                                        "hispanicBoard": 0,
                                                                        "nativeBoard": 0,
                                                                        "whiteBoard": 0,
                                                                        "multiBoard": 0,
                                                                        "preferBoard": 0
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                            mets.append(newMetR)
                                    else:
                                        newMetS = {
                                            "label": "sexRep",
                                            "metrics": [
                                                {
                                                    "label": dmet.s26,
                                                    "value": [
                                                        {
                                                            "label": dmet.s27,
                                                            "value": [
                                                                {
                                                                    "heteroCSuite": 0,
                                                                    "homoCSuite": 0,
                                                                    "biCSuite": 0,
                                                                    "preferCSuite": 0,
                                                                    "heteroEmployees": 0,
                                                                    "homoEmployees": 0,
                                                                    "biEmployees": 0,
                                                                    "preferEmployees": 0,
                                                                    "heteroBoard": 0,
                                                                    "homoBoard": 0,
                                                                    "biBoard": 0,
                                                                    "preferBoard": 0
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                        mets.append(newMetS)
                                        if ([z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"]):
                                            raceData = [z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"][0]
                                            if ([a for a in raceData["metrics"] if a["label"] == dmet.s26]):
                                                yearDataR = [aa for aa in raceData["metrics"] if aa["label"] == dmet.s26][0]
                                                if ([bb for bb in yearDataR["value"] if bb["label"] == dmet.s27]):
                                                    pass
                                                else:
                                                    newMetR = {
                                                        "label": "raceRep",
                                                        "metrics": [
                                                            {
                                                                "label": dmet.s26,
                                                                "value": [
                                                                    {
                                                                        "label": dmet.s27,
                                                                        "value": [
                                                                            {
                                                                                "asianCSuite": 0,
                                                                                "hawaiianCSuite": 0,
                                                                                "blackCSuite": 0,
                                                                                "hispanicCSuite": 0,
                                                                                "nativeCSuite": 0,
                                                                                "whiteCSuite": 0,
                                                                                "multiCSuite": 0,
                                                                                "preferCSuite": 0,
                                                                                "asianEmployees": 0,
                                                                                "hawaiianEmployees": 0,
                                                                                "blackEmployees": 0,
                                                                                "hispanicEmployees": 0,
                                                                                "nativeEmployees": 0,
                                                                                "whiteEmployees": 0,
                                                                                "multiEmployees": 0,
                                                                                "preferEmployees": 0,
                                                                                "asianBoard": 0,
                                                                                "hawaiianBoard": 0,
                                                                                "blackBoard": 0,
                                                                                "hispanicBoard": 0,
                                                                                "nativeBoard": 0,
                                                                                "whiteBoard": 0,
                                                                                "multiBoard": 0,
                                                                                "preferBoard": 0
                                                                            }
                                                                        ]
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                    mets.append(newMetR)
                                            else:
                                                newMetR = {
                                                    "label": "raceRep",
                                                    "metrics": [
                                                        {
                                                            "label": dmet.s26,
                                                            "value": [
                                                                {
                                                                    "label": dmet.s27,
                                                                    "value": [
                                                                        {
                                                                            "asianCSuite": 0,
                                                                            "hawaiianCSuite": 0,
                                                                            "blackCSuite": 0,
                                                                            "hispanicCSuite": 0,
                                                                            "nativeCSuite": 0,
                                                                            "whiteCSuite": 0,
                                                                            "multiCSuite": 0,
                                                                            "preferCSuite": 0,
                                                                            "asianEmployees": 0,
                                                                            "hawaiianEmployees": 0,
                                                                            "blackEmployees": 0,
                                                                            "hispanicEmployees": 0,
                                                                            "nativeEmployees": 0,
                                                                            "whiteEmployees": 0,
                                                                            "multiEmployees": 0,
                                                                            "preferEmployees": 0,
                                                                            "asianBoard": 0,
                                                                            "hawaiianBoard": 0,
                                                                            "blackBoard": 0,
                                                                            "hispanicBoard": 0,
                                                                            "nativeBoard": 0,
                                                                            "whiteBoard": 0,
                                                                            "multiBoard": 0,
                                                                            "preferBoard": 0
                                                                        }
                                                                    ]
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                                mets.append(newMetR)
                                        else:
                                            newMetR = {
                                                "label": "raceRep",
                                                "metrics": [
                                                    {
                                                        "label": dmet.s26,
                                                        "value": [
                                                            {
                                                                "label": dmet.s27,
                                                                "value": [
                                                                    {
                                                                        "asianCSuite": 0,
                                                                        "hawaiianCSuite": 0,
                                                                        "blackCSuite": 0,
                                                                        "hispanicCSuite": 0,
                                                                        "nativeCSuite": 0,
                                                                        "whiteCSuite": 0,
                                                                        "multiCSuite": 0,
                                                                        "preferCSuite": 0,
                                                                        "asianEmployees": 0,
                                                                        "hawaiianEmployees": 0,
                                                                        "blackEmployees": 0,
                                                                        "hispanicEmployees": 0,
                                                                        "nativeEmployees": 0,
                                                                        "whiteEmployees": 0,
                                                                        "multiEmployees": 0,
                                                                        "preferEmployees": 0,
                                                                        "asianBoard": 0,
                                                                        "hawaiianBoard": 0,
                                                                        "blackBoard": 0,
                                                                        "hispanicBoard": 0,
                                                                        "nativeBoard": 0,
                                                                        "whiteBoard": 0,
                                                                        "multiBoard": 0,
                                                                        "preferBoard": 0
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                            mets.append(newMetR)

                                else:
                                    newMetS = {
                                            "label": "sexRep",
                                            "metrics": [
                                                {
                                                    "label": dmet.s26,
                                                    "value": [
                                                        {
                                                            "label": dmet.s27,
                                                            "value": [
                                                                {
                                                                    "heteroCSuite": 0,
                                                                    "homoCSuite": 0,
                                                                    "biCSuite": 0,
                                                                    "preferCSuite": 0,
                                                                    "heteroEmployees": 0,
                                                                    "homoEmployees": 0,
                                                                    "biEmployees": 0,
                                                                    "preferEmployees": 0,
                                                                    "heteroBoard": 0,
                                                                    "homoBoard": 0,
                                                                    "biBoard": 0,
                                                                    "preferBoard": 0
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                    mets.append(newMetS)
                                    if ([z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"]):
                                        raceData = [z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"][0]
                                        if ([a for a in raceData["metrics"] if a["label"] == dmet.s26]):
                                            yearDataR = [aa for aa in raceData["metrics"] if aa["label"] == dmet.s26][0]
                                            if ([bb for bb in yearDataR["value"] if bb["label"] == dmet.s27]):
                                                pass
                                            else:
                                                newMetR = {
                                                    "label": "raceRep",
                                                    "metrics": [
                                                        {
                                                            "label": dmet.s26,
                                                            "value": [
                                                                {
                                                                    "label": dmet.s27,
                                                                    "value": [
                                                                        {
                                                                            "asianCSuite": 0,
                                                                            "hawaiianCSuite": 0,
                                                                            "blackCSuite": 0,
                                                                            "hispanicCSuite": 0,
                                                                            "nativeCSuite": 0,
                                                                            "whiteCSuite": 0,
                                                                            "multiCSuite": 0,
                                                                            "preferCSuite": 0,
                                                                            "asianEmployees": 0,
                                                                            "hawaiianEmployees": 0,
                                                                            "blackEmployees": 0,
                                                                            "hispanicEmployees": 0,
                                                                            "nativeEmployees": 0,
                                                                            "whiteEmployees": 0,
                                                                            "multiEmployees": 0,
                                                                            "preferEmployees": 0,
                                                                            "asianBoard": 0,
                                                                            "hawaiianBoard": 0,
                                                                            "blackBoard": 0,
                                                                            "hispanicBoard": 0,
                                                                            "nativeBoard": 0,
                                                                            "whiteBoard": 0,
                                                                            "multiBoard": 0,
                                                                            "preferBoard": 0
                                                                        }
                                                                    ]
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                                mets.append(newMetR)
                                        else:
                                            newMetR = {
                                                "label": "raceRep",
                                                "metrics": [
                                                    {
                                                        "label": dmet.s26,
                                                        "value": [
                                                            {
                                                                "label": dmet.s27,
                                                                "value": [
                                                                    {
                                                                        "asianCSuite": 0,
                                                                        "hawaiianCSuite": 0,
                                                                        "blackCSuite": 0,
                                                                        "hispanicCSuite": 0,
                                                                        "nativeCSuite": 0,
                                                                        "whiteCSuite": 0,
                                                                        "multiCSuite": 0,
                                                                        "preferCSuite": 0,
                                                                        "asianEmployees": 0,
                                                                        "hawaiianEmployees": 0,
                                                                        "blackEmployees": 0,
                                                                        "hispanicEmployees": 0,
                                                                        "nativeEmployees": 0,
                                                                        "whiteEmployees": 0,
                                                                        "multiEmployees": 0,
                                                                        "preferEmployees": 0,
                                                                        "asianBoard": 0,
                                                                        "hawaiianBoard": 0,
                                                                        "blackBoard": 0,
                                                                        "hispanicBoard": 0,
                                                                        "nativeBoard": 0,
                                                                        "whiteBoard": 0,
                                                                        "multiBoard": 0,
                                                                        "preferBoard": 0
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                            mets.append(newMetR)
                                    else:
                                        newMetR = {
                                            "label": "raceRep",
                                            "metrics": [
                                                {
                                                    "label": dmet.s26,
                                                    "value": [
                                                        {
                                                            "label": dmet.s27,
                                                            "value": [
                                                                {
                                                                    "asianCSuite": 0,
                                                                    "hawaiianCSuite": 0,
                                                                    "blackCSuite": 0,
                                                                    "hispanicCSuite": 0,
                                                                    "nativeCSuite": 0,
                                                                    "whiteCSuite": 0,
                                                                    "multiCSuite": 0,
                                                                    "preferCSuite": 0,
                                                                    "asianEmployees": 0,
                                                                    "hawaiianEmployees": 0,
                                                                    "blackEmployees": 0,
                                                                    "hispanicEmployees": 0,
                                                                    "nativeEmployees": 0,
                                                                    "whiteEmployees": 0,
                                                                    "multiEmployees": 0,
                                                                    "preferEmployees": 0,
                                                                    "asianBoard": 0,
                                                                    "hawaiianBoard": 0,
                                                                    "blackBoard": 0,
                                                                    "hispanicBoard": 0,
                                                                    "nativeBoard": 0,
                                                                    "whiteBoard": 0,
                                                                    "multiBoard": 0,
                                                                    "preferBoard": 0
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                        mets.append(newMetR)
                            else:
                                newMetS = {
                                    "label": "sexRep",
                                    "metrics": [
                                        {
                                            "label": dmet.s26,
                                            "value": [
                                                {
                                                    "label": dmet.s27,
                                                    "value": [
                                                        {
                                                            "heteroCSuite": 0,
                                                            "homoCSuite": 0,
                                                            "biCSuite": 0,
                                                            "preferCSuite": 0,
                                                            "heteroEmployees": 0,
                                                            "homoEmployees": 0,
                                                            "biEmployees": 0,
                                                            "preferEmployees": 0,
                                                            "heteroBoard": 0,
                                                            "homoBoard": 0,
                                                            "biBoard": 0,
                                                            "preferBoard": 0
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                                mets.append(newMetS)
                                if ([z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"]):
                                    raceData = [z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"][0]
                                    if ([a for a in raceData["metrics"] if a["label"] == dmet.s26]):
                                        yearDataR = [aa for aa in raceData["metrics"] if aa["label"] == dmet.s26][0]
                                        if ([bb for bb in yearDataR["value"] if bb["label"] == dmet.s27]):
                                            pass
                                        else:
                                            newMetR = {
                                                "label": "raceRep",
                                                "metrics": [
                                                    {
                                                        "label": dmet.s26,
                                                        "value": [
                                                            {
                                                                "label": dmet.s27,
                                                                "value": [
                                                                    {
                                                                        "asianCSuite": 0,
                                                                        "hawaiianCSuite": 0,
                                                                        "blackCSuite": 0,
                                                                        "hispanicCSuite": 0,
                                                                        "nativeCSuite": 0,
                                                                        "whiteCSuite": 0,
                                                                        "multiCSuite": 0,
                                                                        "preferCSuite": 0,
                                                                        "asianEmployees": 0,
                                                                        "hawaiianEmployees": 0,
                                                                        "blackEmployees": 0,
                                                                        "hispanicEmployees": 0,
                                                                        "nativeEmployees": 0,
                                                                        "whiteEmployees": 0,
                                                                        "multiEmployees": 0,
                                                                        "preferEmployees": 0,
                                                                        "asianBoard": 0,
                                                                        "hawaiianBoard": 0,
                                                                        "blackBoard": 0,
                                                                        "hispanicBoard": 0,
                                                                        "nativeBoard": 0,
                                                                        "whiteBoard": 0,
                                                                        "multiBoard": 0,
                                                                        "preferBoard": 0
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                            mets.append(newMetR)
                                    else:
                                        newMetR = {
                                            "label": "raceRep",
                                            "metrics": [
                                                {
                                                    "label": dmet.s26,
                                                    "value": [
                                                        {
                                                            "label": dmet.s27,
                                                            "value": [
                                                                {
                                                                    "asianCSuite": 0,
                                                                    "hawaiianCSuite": 0,
                                                                    "blackCSuite": 0,
                                                                    "hispanicCSuite": 0,
                                                                    "nativeCSuite": 0,
                                                                    "whiteCSuite": 0,
                                                                    "multiCSuite": 0,
                                                                    "preferCSuite": 0,
                                                                    "asianEmployees": 0,
                                                                    "hawaiianEmployees": 0,
                                                                    "blackEmployees": 0,
                                                                    "hispanicEmployees": 0,
                                                                    "nativeEmployees": 0,
                                                                    "whiteEmployees": 0,
                                                                    "multiEmployees": 0,
                                                                    "preferEmployees": 0,
                                                                    "asianBoard": 0,
                                                                    "hawaiianBoard": 0,
                                                                    "blackBoard": 0,
                                                                    "hispanicBoard": 0,
                                                                    "nativeBoard": 0,
                                                                    "whiteBoard": 0,
                                                                    "multiBoard": 0,
                                                                    "preferBoard": 0
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                        mets.append(newMetR)
                                else:
                                    newMetR = {
                                        "label": "raceRep",
                                        "metrics": [
                                            {
                                                "label": dmet.s26,
                                                "value": [
                                                    {
                                                        "label": dmet.s27,
                                                        "value": [
                                                            {
                                                                "asianCSuite": 0,
                                                                "hawaiianCSuite": 0,
                                                                "blackCSuite": 0,
                                                                "hispanicCSuite": 0,
                                                                "nativeCSuite": 0,
                                                                "whiteCSuite": 0,
                                                                "multiCSuite": 0,
                                                                "preferCSuite": 0,
                                                                "asianEmployees": 0,
                                                                "hawaiianEmployees": 0,
                                                                "blackEmployees": 0,
                                                                "hispanicEmployees": 0,
                                                                "nativeEmployees": 0,
                                                                "whiteEmployees": 0,
                                                                "multiEmployees": 0,
                                                                "preferEmployees": 0,
                                                                "asianBoard": 0,
                                                                "hawaiianBoard": 0,
                                                                "blackBoard": 0,
                                                                "hispanicBoard": 0,
                                                                "nativeBoard": 0,
                                                                "whiteBoard": 0,
                                                                "multiBoard": 0,
                                                                "preferBoard": 0
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                        ]
                                    }
                                    mets.append(newMetR)
                    else:
                        newMetG = {
                            "label": "genderRep",
                            "metrics": [
                                {
                                    "label": dmet.s26,
                                    "value": [
                                        {
                                        "label": dmet.s27,
                                        "value": [
                                            {
                                            "maleCSuite": dmet.s1,
                                            "femaleCSuite": dmet.s2,
                                            "genderCSuite": dmet.s3,
                                            "transCSuite": dmet.s4,
                                            "preferCSuite": dmet.s5,
                                            "maleEmployees": dmet.s6,
                                            "femaleEmployees": dmet.s7,
                                            "genderEmployees": dmet.s8,
                                            "transEmployees": dmet.s9,
                                            "preferEmployees": dmet.s10,
                                            "maleBoard": dmet.s11,
                                            "femaleBoard": dmet.s12,
                                            "genderBoard": dmet.s13,
                                            "transBoard": dmet.s14,
                                            "preferBoard": dmet.s15
                                        }
                                        ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets.append(newMetG)
                        newMetS = {
                            "label": "sexRep",
                            "metrics": [
                                {
                                    "label": dmet.s26,
                                    "value": [
                                        {
                                            "label": dmet.s27,
                                            "value": [
                                                {
                                                    "heteroCSuite": 0,
                                                    "homoCSuite": 0,
                                                    "biCSuite": 0,
                                                    "preferCSuite": 0,
                                                    "heteroEmployees": 0,
                                                    "homoEmployees": 0,
                                                    "biEmployees": 0,
                                                    "preferEmployees": 0,
                                                    "heteroBoard": 0,
                                                    "homoBoard": 0,
                                                    "biBoard": 0,
                                                    "preferBoard": 0
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets.append(newMetS)
                        newMetR = {
                            "label": "raceRep",
                            "metrics": [
                                {
                                    "label": dmet.s26,
                                    "value": [
                                        {
                                            "label": dmet.s27,
                                            "value": [
                                                {
                                                    "asianCSuite": 0,
                                                    "hawaiianCSuite": 0,
                                                    "blackCSuite": 0,
                                                    "hispanicCSuite": 0,
                                                    "nativeCSuite": 0,
                                                    "whiteCSuite": 0,
                                                    "multiCSuite": 0,
                                                    "preferCSuite": 0,
                                                    "asianEmployees": 0,
                                                    "hawaiianEmployees": 0,
                                                    "blackEmployees": 0,
                                                    "hispanicEmployees": 0,
                                                    "nativeEmployees": 0,
                                                    "whiteEmployees": 0,
                                                    "multiEmployees": 0,
                                                    "preferEmployees": 0,
                                                    "asianBoard": 0,
                                                    "hawaiianBoard": 0,
                                                    "blackBoard": 0,
                                                    "hispanicBoard": 0,
                                                    "nativeBoard": 0,
                                                    "whiteBoard": 0,
                                                    "multiBoard": 0,
                                                    "preferBoard": 0
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets.append(newMetR)
                else:
                    newMetG = {
                    "label": "genderRep",
                    "metrics": [
                        {
                            "label": dmet.s26,
                            "value": [
                                {
                                "label": dmet.s27,
                                "value": [
                                    {
                                    "maleCSuite": dmet.s1,
                                    "femaleCSuite": dmet.s2,
                                    "genderCSuite": dmet.s3,
                                    "transCSuite": dmet.s4,
                                    "preferCSuite": dmet.s5,
                                    "maleEmployees": dmet.s6,
                                    "femaleEmployees": dmet.s7,
                                    "genderEmployees": dmet.s8,
                                    "transEmployees": dmet.s9,
                                    "preferEmployees": dmet.s10,
                                    "maleBoard": dmet.s11,
                                    "femaleBoard": dmet.s12,
                                    "genderBoard": dmet.s13,
                                    "transBoard": dmet.s14,
                                    "preferBoard": dmet.s15
                                }
                                ]
                                }
                            ]
                        }
                    ]
                    }
                    mets.append(newMetG)
                    newMetS = {
                        "label": "sexRep",
                        "metrics": [
                            {
                                "label": dmet.s26,
                                "value": [
                                    {
                                        "label": dmet.s27,
                                        "value": [
                                            {
                                                "heteroCSuite": 0,
                                                "homoCSuite": 0,
                                                "biCSuite": 0,
                                                "preferCSuite": 0,
                                                "heteroEmployees": 0,
                                                "homoEmployees": 0,
                                                "biEmployees": 0,
                                                "preferEmployees": 0,
                                                "heteroBoard": 0,
                                                "homoBoard": 0,
                                                "biBoard": 0,
                                                "preferBoard": 0
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMetS)
                    newMetR = {
                        "label": "raceRep",
                        "metrics": [
                            {
                                "label": dmet.s26,
                                "value": [
                                    {
                                        "label": dmet.s27,
                                        "value": [
                                            {
                                                "asianCSuite": 0,
                                                "hawaiianCSuite": 0,
                                                "blackCSuite": 0,
                                                "hispanicCSuite": 0,
                                                "nativeCSuite": 0,
                                                "whiteCSuite": 0,
                                                "multiCSuite": 0,
                                                "preferCSuite": 0,
                                                "asianEmployees": 0,
                                                "hawaiianEmployees": 0,
                                                "blackEmployees": 0,
                                                "hispanicEmployees": 0,
                                                "nativeEmployees": 0,
                                                "whiteEmployees": 0,
                                                "multiEmployees": 0,
                                                "preferEmployees": 0,
                                                "asianBoard": 0,
                                                "hawaiianBoard": 0,
                                                "blackBoard": 0,
                                                "hispanicBoard": 0,
                                                "nativeBoard": 0,
                                                "whiteBoard": 0,
                                                "multiBoard": 0,
                                                "preferBoard": 0
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMetR)


                target = {
                    "diversitymeasure": mets
                }
                user.update(target)
                callConnect.container8.upsert_item(body=user)
                user2 = {
                    "id": dmet.s25,
                    "surveymeasure": []
                }
                callConnect.container9.upsert_item(body=user2)
        

"""
Endpoint used to update the diversity metrics.
"""
@diversityroute.post('/diversitymeasureFROG')
async def diversity_measure_frog(dmet: DiversityMeasureFrog):
    try:
        db_result = read_item(callConnect.container8, dmet.oid, dmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /diversitymeasure container8')
        return {"url": "/", "atype": False}


    if "diversitymeasure" in db_result:
        if dmet.metric == "genderRep":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "diversitymeasure": []
            }
            try:
                db_resultC = read_item(callConnect.container7, dmet.oid, dmet.email)
            except exceptions.CosmosHttpResponseError as e:
                logging.error('This is an error message for /diversitymeasure')
                return {"url": "/", "atype": False}

            if "carbonmeasure" in db_resultC:
                user2C = {
                    "id": db_resultC["id"],
                    "email": db_resultC["email"],
                    "carbonmeasure": []
                }
                mets2C = [z for z in db_resultC["carbonmeasure"] if z["label"] != "Emissions"]
                
                if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                    emData = [z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"][0]

                    if ([a for a in emData["metrics"] if a["label"] == dmet.s26]):
                        yearData2C = [aa for aa in emData["metrics"] if aa["label"] == dmet.s26][0]
                        if ([bb for bb in yearData2C["value"] if bb["label"] == dmet.s27]):
                            pass
                        else:
                            quarterData2C = [bb for bb in yearData2C["value"] if bb["label"] != dmet.s27]
                            cmeas2C = []
                            cmeas2C.append({
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            })
                            tmeas2C = [a for a in emData["metrics"] if a["label"] != dmet.s26]
                            quarterData2C.append({
                                "label": dmet.s27,
                                "metrics": [
                                    {
                                        "label": "1",
                                        "value": cmeas2C
                                    }
                                ]
                            })
                            tmeas2C.append({
                                "label": dmet.s26,
                                "value": quarterData2C
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)
                    else:
                        cmeas2C = [{
                            "scope1": 0,
                            "scope2": 0,
                            "scope3": 0
                        }]
                        tmeas2C = [a for a in emData["metrics"] if a["label"] != dmet.s26]
                        tmeas2C.append({
                                    "label": dmet.s26,
                                    "value": [
                                        {
                                            "label": dmet.s27,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value": cmeas2C
                                                }
                                            ]
                                        }
                                    ]
                                })
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": tmeas2C
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)
                
                else:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"] if z["label"] != "Emissions"]
                    newMet2C = {
                        "label": "Emissions",
                        "metrics": [
                            {
                                "label": dmet.s26,
                                "value": [
                                    {
                                        "label": dmet.s27,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "scope1": 0,
                                                            "scope2": 0,
                                                            "scope3": 0
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets2C.append(newMet2C)
                    target2C = {
                        "carbonmeasure": mets2C
                    }
                    user2C.update(target2C)
                    callConnect.container7.upsert_item(body=user2C)
        
            
            mets = [z for z in db_result["diversitymeasure"] if z["label"] != "genderRep"]
            if ([z for z in db_result["diversitymeasure"] if z["label"] == "genderRep"]):
                genderData = [z for z in db_result["diversitymeasure"] if z["label"] == "genderRep"][0]

                if ([a for a in genderData["metrics"] if a["label"] == dmet.s26]):
                    yearData = [aa for aa in genderData["metrics"] if aa["label"] == dmet.s26][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != dmet.s27]
                    cmeas = [{
                        "maleCSuite": dmet.s1,
                        "femaleCSuite": dmet.s2,
                        "genderCSuite": dmet.s3,
                        "transCSuite": dmet.s4,
                        "preferCSuite": dmet.s5,
                        "maleManager": dmet.s6,
                        "femaleManager": dmet.s7,
                        "genderManager": dmet.s8,
                        "transManager": dmet.s9,
                        "preferManager": dmet.s10,
                        "maleEmployees": dmet.s11,
                        "femaleEmployees": dmet.s12,
                        "genderEmployees": dmet.s13,
                        "transEmployees": dmet.s14,
                        "preferEmployees": dmet.s15,
                        "maleBoard": dmet.s16,
                        "femaleBoard": dmet.s17,
                        "genderBoard": dmet.s18,
                        "transBoard": dmet.s19,
                        "preferBoard": dmet.s20
                    }]
                    tmeas = [a for a in genderData["metrics"] if a["label"] != dmet.s26]
                    quarterData.append({
                        "label": dmet.s27,
                        "value": cmeas
                    })
                    tmeas.append({
                                "label": dmet.s26,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "genderRep",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "diversitymeasure": mets
                    }
                    user.update(target)
                    callConnect.container8.upsert_item(body=user)
                else:
                    cmeas = [{
                        "maleCSuite": dmet.s1,
                        "femaleCSuite": dmet.s2,
                        "genderCSuite": dmet.s3,
                        "transCSuite": dmet.s4,
                        "preferCSuite": dmet.s5,
                        "maleManager": dmet.s6,
                        "femaleManager": dmet.s7,
                        "genderManager": dmet.s8,
                        "transManager": dmet.s9,
                        "preferManager": dmet.s10,
                        "maleEmployees": dmet.s11,
                        "femaleEmployees": dmet.s12,
                        "genderEmployees": dmet.s13,
                        "transEmployees": dmet.s14,
                        "preferEmployees": dmet.s15,
                        "maleBoard": dmet.s16,
                        "femaleBoard": dmet.s17,
                        "genderBoard": dmet.s18,
                        "transBoard": dmet.s19,
                        "preferBoard": dmet.s20
                    }]
                    tmeas = [a for a in genderData["metrics"] if a["label"] != dmet.s26]
                    tmeas.append({
                                "label": dmet.s26,
                                "value": [
                                    {
                                        "label": dmet.s27,
                                        "value": cmeas
                                    }
                                ]
                            })
                    newMet = {
                        "label": "genderRep",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "diversitymeasure": mets
                    }
                    user.update(target)
                    callConnect.container8.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "diversitymeasure": []
                }
                mets = [z for z in db_result["diversitymeasure"] if z["label"] != "genderRep"]
                newMet = {
                    "label": "genderRep",
                    "metrics": [
                        {
                            "label": dmet.s26,
                            "value": [
                                {
                                "label": dmet.s27,
                                "value": [
                                    {
                                        "maleCSuite": dmet.s1,
                                        "femaleCSuite": dmet.s2,
                                        "genderCSuite": dmet.s3,
                                        "transCSuite": dmet.s4,
                                        "preferCSuite": dmet.s5,
                                        "maleManager": dmet.s6,
                                        "femaleManager": dmet.s7,
                                        "genderManager": dmet.s8,
                                        "transManager": dmet.s9,
                                        "preferManager": dmet.s10,
                                        "maleEmployees": dmet.s11,
                                        "femaleEmployees": dmet.s12,
                                        "genderEmployees": dmet.s13,
                                        "transEmployees": dmet.s14,
                                        "preferEmployees": dmet.s15,
                                        "maleBoard": dmet.s16,
                                        "femaleBoard": dmet.s17,
                                        "genderBoard": dmet.s18,
                                        "transBoard": dmet.s19,
                                        "preferBoard": dmet.s20
                                    }
                                ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                newMetS = {
                    "label": "sexRep",
                    "metrics": [
                        {
                            "label": dmet.s26,
                            "value": [
                                {
                                    "label": dmet.s27,
                                    "value": [
                                        {
                                            "heteroCSuite": 0,
                                            "homoCSuite": 0,
                                            "biCSuite": 0,
                                            "preferCSuite": 0,
                                            "heteroEmployees": 0,
                                            "homoEmployees": 0,
                                            "biEmployees": 0,
                                            "preferEmployees": 0,
                                            "heteroBoard": 0,
                                            "homoBoard": 0,
                                            "biBoard": 0,
                                            "preferBoard": 0
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMetS)
                newMetR = {
                    "label": "raceRep",
                    "metrics": [
                        {
                            "label": dmet.s26,
                            "value": [
                                {
                                    "label": dmet.s27,
                                    "value": [
                                        {
                                            "asianCSuite": 0,
                                            "hawaiianCSuite": 0,
                                            "blackCSuite": 0,
                                            "hispanicCSuite": 0,
                                            "nativeCSuite": 0,
                                            "whiteCSuite": 0,
                                            "multiCSuite": 0,
                                            "preferCSuite": 0,
                                            "asianManager": 0,
                                            "hawaiianManager": 0,
                                            "blackManager": 0,
                                            "hispanicManager": 0,
                                            "nativeManager": 0,
                                            "whiteManager": 0,
                                            "multiManager": 0,
                                            "preferManager": 0,
                                            "asianEmployees": 0,
                                            "hawaiianEmployees": 0,
                                            "blackEmployees": 0,
                                            "hispanicEmployees": 0,
                                            "nativeEmployees": 0,
                                            "whiteEmployees": 0,
                                            "multiEmployees": 0,
                                            "preferEmployees": 0,
                                            "asianBoard": 0,
                                            "hawaiianBoard": 0,
                                            "blackBoard": 0,
                                            "hispanicBoard": 0,
                                            "nativeBoard": 0,
                                            "whiteBoard": 0,
                                            "multiBoard": 0,
                                            "preferBoard": 0
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMetR)
                target = {
                    "diversitymeasure": mets
                }
                user.update(target)
                callConnect.container8.upsert_item(body=user)
        if dmet.metric == "sexRep":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "diversitymeasure": []
            }
            mets = [z for z in db_result["diversitymeasure"] if z["label"] != "sexRep"]
            if ([z for z in db_result["diversitymeasure"] if z["label"] == "sexRep"]):
                sexData = [z for z in db_result["diversitymeasure"] if z["label"] == "sexRep"][0]
                if ([a for a in sexData["metrics"] if a["label"] == dmet.s26]):
                    yearData = [aa for aa in sexData["metrics"] if aa["label"] == dmet.s26][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != dmet.s27]
                    cmeas = [{
                        "heteroCSuite": dmet.s1,
                        "homoCSuite": dmet.s2,
                        "biCSuite": dmet.s3,
                        "preferCSuite": dmet.s4,
                        "heteroEmployees": dmet.s5,
                        "homoEmployees": dmet.s6,
                        "biEmployees": dmet.s7,
                        "preferEmployees": dmet.s8,
                        "heteroBoard": dmet.s9,
                        "homoBoard": dmet.s10,
                        "biBoard": dmet.s11,
                        "preferBoard": dmet.s12
                    }]
                    tmeas = [a for a in sexData["metrics"] if a["label"] != dmet.s26]
                    quarterData.append({
                        "label": dmet.s27,
                        "value": cmeas
                    })
                    tmeas.append({
                                "label": dmet.s26,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "sexRep",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "diversitymeasure": mets
                    }
                    user.update(target)
                    callConnect.container8.upsert_item(body=user)
                else:
                    cmeas = [{
                        "heteroCSuite": dmet.s1,
                        "homoCSuite": dmet.s2,
                        "biCSuite": dmet.s3,
                        "preferCSuite": dmet.s4,
                        "heteroEmployees": dmet.s5,
                        "homoEmployees": dmet.s6,
                        "biEmployees": dmet.s7,
                        "preferEmployees": dmet.s8,
                        "heteroBoard": dmet.s9,
                        "homoBoard": dmet.s10,
                        "biBoard": dmet.s11,
                        "preferBoard": dmet.s12
                    }]
                    tmeas = [a for a in sexData["metrics"] if a["label"] != dmet.s26]
                    tmeas.append({
                                "label": dmet.s26,
                                "value": [
                                    {
                                        "label": dmet.s27,
                                        "value": cmeas
                                    }
                                ]
                            })
                    newMet = {
                        "label": "sexRep",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "diversitymeasure": mets
                    }
                    user.update(target)
                    callConnect.container8.upsert_item(body=user)
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "diversitymeasure": []
                }
                mets = [z for z in db_result["diversitymeasure"] if z["label"] != "sexRep"]
                newMet = {
                    "label": "sexRep",
                    "metrics": [
                        {
                            "label": dmet.s26,
                            "value": [
                                {
                                    "label": dmet.s27,
                                    "value": [
                                        {
                                            "heteroCSuite": dmet.s1,
                                            "homoCSuite": dmet.s2,
                                            "biCSuite": dmet.s3,
                                            "preferCSuite": dmet.s4,
                                            "heteroEmployees": dmet.s5,
                                            "homoEmployees": dmet.s6,
                                            "biEmployees": dmet.s7,
                                            "preferEmployees": dmet.s8,
                                            "heteroBoard": dmet.s9,
                                            "homoBoard": dmet.s10,
                                            "biBoard": dmet.s11,
                                            "preferBoard": dmet.s12
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "diversitymeasure": mets
                }
                user.update(target)
                callConnect.container8.upsert_item(body=user)
        if dmet.metric == "raceRep":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "diversitymeasure": []
            }
            mets = [z for z in db_result["diversitymeasure"] if z["label"] != "raceRep"]
            if ([z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"]):
                raceData = [z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"][0]

                if ([a for a in raceData["metrics"] if a["label"] == dmet.s26]):
                    yearData = [aa for aa in raceData["metrics"] if aa["label"] == dmet.s26][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != dmet.s27]
                    cmeas = [{
                        "asianCSuite": dmet.s1,
                        "hawaiianCSuite": dmet.s2,
                        "blackCSuite": dmet.s3,
                        "hispanicCSuite": dmet.s4,
                        "nativeCSuite": dmet.s5,
                        "whiteCSuite": dmet.s6,
                        "multiCSuite": dmet.s7,
                        "preferCSuite": dmet.s8,
                        "asianManager": dmet.s9,
                        "hawaiianManager": dmet.s10,
                        "blackManager": dmet.s11,
                        "hispanicManager": dmet.s12,
                        "nativeManager": dmet.s13,
                        "whiteManager": dmet.s14,
                        "multiManager": dmet.s15,
                        "preferManager": dmet.s16,
                        "asianEmployees": dmet.s17,
                        "hawaiianEmployees": dmet.s18,
                        "blackEmployees": dmet.s19,
                        "hispanicEmployees": dmet.s20,
                        "nativeEmployees": dmet.s21,
                        "whiteEmployees": dmet.s22,
                        "multiEmployees": dmet.s23,
                        "preferEmployees": dmet.s24,
                        "asianBoard": dmet.s28,
                        "hawaiianBoard": dmet.s29,
                        "blackBoard": dmet.s30,
                        "hispanicBoard": dmet.s31,
                        "nativeBoard": dmet.s32,
                        "whiteBoard": dmet.s33,
                        "multiBoard": dmet.s34,
                        "preferBoard": dmet.s35
                    }]
                    tmeas = [a for a in raceData["metrics"] if a["label"] != dmet.s26]
                    quarterData.append({
                        "label": dmet.s27,
                        "value": cmeas
                    })
                    tmeas.append({
                                "label": dmet.s26,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "raceRep",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "diversitymeasure": mets
                    }
                    user.update(target)
                    callConnect.container8.upsert_item(body=user)
                else:
                    cmeas = [{
                        "asianCSuite": dmet.s1,
                        "hawaiianCSuite": dmet.s2,
                        "blackCSuite": dmet.s3,
                        "hispanicCSuite": dmet.s4,
                        "nativeCSuite": dmet.s5,
                        "whiteCSuite": dmet.s6,
                        "multiCSuite": dmet.s7,
                        "preferCSuite": dmet.s8,
                        "asianManager": dmet.s9,
                        "hawaiianManager": dmet.s10,
                        "blackManager": dmet.s11,
                        "hispanicManager": dmet.s12,
                        "nativeManager": dmet.s13,
                        "whiteManager": dmet.s14,
                        "multiManager": dmet.s15,
                        "preferManager": dmet.s16,
                        "asianEmployees": dmet.s17,
                        "hawaiianEmployees": dmet.s18,
                        "blackEmployees": dmet.s19,
                        "hispanicEmployees": dmet.s20,
                        "nativeEmployees": dmet.s21,
                        "whiteEmployees": dmet.s22,
                        "multiEmployees": dmet.s23,
                        "preferEmployees": dmet.s24,
                        "asianBoard": dmet.s28,
                        "hawaiianBoard": dmet.s29,
                        "blackBoard": dmet.s30,
                        "hispanicBoard": dmet.s31,
                        "nativeBoard": dmet.s32,
                        "whiteBoard": dmet.s33,
                        "multiBoard": dmet.s34,
                        "preferBoard": dmet.s35
                    }]
                    tmeas = [a for a in raceData["metrics"] if a["label"] != dmet.s26]
                    tmeas.append({
                                "label": dmet.s26,
                                "value": [
                                    {
                                        "label": dmet.s27,
                                        "value": cmeas
                                    }
                                ]
                            })
                    newMet = {
                        "label": "raceRep",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "diversitymeasure": mets
                    }
                    user.update(target)
                    callConnect.container8.upsert_item(body=user)
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "diversitymeasure": []
                }
                mets = [z for z in db_result["diversitymeasure"] if z["label"] != "raceRep"]
                newMet = {
                    "label": "raceRep",
                    "metrics": [
                        {
                            "label": dmet.s26,
                            "value": [
                                {
                                    "label": dmet.s27,
                                    "value": [
                                        {
                                            "asianCSuite": dmet.s1,
                                            "hawaiianCSuite": dmet.s2,
                                            "blackCSuite": dmet.s3,
                                            "hispanicCSuite": dmet.s4,
                                            "nativeCSuite": dmet.s5,
                                            "whiteCSuite": dmet.s6,
                                            "multiCSuite": dmet.s7,
                                            "preferCSuite": dmet.s8,
                                            "asianManager": dmet.s9,
                                            "hawaiianManager": dmet.s10,
                                            "blackManager": dmet.s11,
                                            "hispanicManager": dmet.s12,
                                            "nativeManager": dmet.s13,
                                            "whiteManager": dmet.s14,
                                            "multiManager": dmet.s15,
                                            "preferManager": dmet.s16,
                                            "asianEmployees": dmet.s17,
                                            "hawaiianEmployees": dmet.s18,
                                            "blackEmployees": dmet.s19,
                                            "hispanicEmployees": dmet.s20,
                                            "nativeEmployees": dmet.s21,
                                            "whiteEmployees": dmet.s22,
                                            "multiEmployees": dmet.s23,
                                            "preferEmployees": dmet.s24,
                                            "asianBoard": dmet.s28,
                                            "hawaiianBoard": dmet.s29,
                                            "blackBoard": dmet.s30,
                                            "hispanicBoard": dmet.s31,
                                            "nativeBoard": dmet.s32,
                                            "whiteBoard": dmet.s33,
                                            "multiBoard": dmet.s34,
                                            "preferBoard": dmet.s35
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "diversitymeasure": mets
                }
                user.update(target)
                callConnect.container8.upsert_item(body=user)
        if dmet.metric == "SurveyCode":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "diversitymeasure": []
            }

            try:
                db_resultC = read_item(callConnect.container7, dmet.oid, dmet.email)
            except exceptions.CosmosHttpResponseError as e:
                logging.error('This is an error message for /diversitymeasure')
                return {"url": "/", "atype": False}

            if "carbonmeasure" in db_resultC:
                user2C = {
                    "id": db_resultC["id"],
                    "email": db_resultC["email"],
                    "carbonmeasure": []
                }
                mets2C = [z for z in db_resultC["carbonmeasure"] if z["label"] != "Emissions"]
                
                if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                    emData = [z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"][0]

                    if ([a for a in emData["metrics"] if a["label"] == dmet.s26]):
                        yearData2C = [aa for aa in emData["metrics"] if aa["label"] == dmet.s26][0]
                        if ([bb for bb in yearData2C["value"] if bb["label"] == dmet.s27]):
                            pass
                        else:
                            quarterData2C = [bb for bb in yearData2C["value"] if bb["label"] != dmet.s27]
                            cmeas2C = []
                            cmeas2C.append({
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            })
                            tmeas2C = [a for a in emData["metrics"] if a["label"] != dmet.s26]
                            quarterData2C.append({
                                "label": dmet.s27,
                                "metrics": [
                                    {
                                        "label": "1",
                                        "value": cmeas2C
                                    }
                                ]
                            })
                            tmeas2C.append({
                                "label": dmet.s26,
                                "value": quarterData2C
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)
                    else:
                        cmeas2C = [{
                            "scope1": 0,
                            "scope2": 0,
                            "scope3": 0
                        }]
                        tmeas2C = [a for a in emData["metrics"] if a["label"] != dmet.s26]
                        tmeas2C.append({
                                    "label": dmet.s26,
                                    "value": [
                                        {
                                            "label": dmet.s27,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value": cmeas2C
                                                }
                                            ]
                                        }
                                    ]
                                })
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": tmeas2C
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)
                
                else:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"] if z["label"] != "Emissions"]
                    newMet2C = {
                        "label": "Emissions",
                        "metrics": [
                            {
                                "label": dmet.s26,
                                "value": [
                                    {
                                        "label": dmet.s27,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "scope1": 0,
                                                            "scope2": 0,
                                                            "scope3": 0
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets2C.append(newMet2C)
                    target2C = {
                        "carbonmeasure": mets2C
                    }
                    user2C.update(target2C)
                    callConnect.container7.upsert_item(body=user2C)

            mets = [z for z in db_result["diversitymeasure"] if z["label"] != "SurveyCode"]
            if ([z for z in db_result["diversitymeasure"] if z["label"] == "SurveyCode"]):
                surveyData = [z for z in db_result["diversitymeasure"] if z["label"] == "SurveyCode"][0]

                if ([a for a in surveyData["metrics"] if a["label"] == dmet.s26]):
                    yearData = [aa for aa in surveyData["metrics"] if aa["label"] == dmet.s26][0]
                    if ([bb for bb in yearData["value"] if bb["label"] == dmet.s27]):
                        pass
                    else:
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != dmet.s27]
                        cmeas = [{
                            "code": dmet.s25
                        }]
                        tmeas = [a for a in surveyData["metrics"] if a["label"] != dmet.s26]
                        quarterData.append({
                            "label": dmet.s27,
                            "value": cmeas
                        })
                        tmeas.append({
                                    "label": dmet.s26,
                                    "value": quarterData
                                })
                        newMet = {
                            "label": "SurveyCode",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "diversitymeasure": mets
                        }
                        user.update(target)
                        callConnect.container8.upsert_item(body=user)
                        user2 = {
                            "id": dmet.s25,
                            "surveymeasure": []
                        }
                        callConnect.container9.upsert_item(body=user2)
                else:
                    cmeas = [{
                        "code": dmet.s25
                    }]
                    tmeas = [a for a in surveyData["metrics"] if a["label"] != dmet.s26]
                    tmeas.append({
                                "label": dmet.s26,
                                "value": [
                                    {
                                        "label": dmet.s27,
                                        "value": cmeas
                                    }
                                ]
                            })
                    newMet = {
                        "label": "SurveyCode",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "diversitymeasure": mets
                    }
                    user.update(target)
                    callConnect.container8.upsert_item(body=user)
                    user2 = {
                        "id": dmet.s25,
                        "surveymeasure": []
                    }
                    callConnect.container9.upsert_item(body=user2)
            else:
                cmeas = [{
                    "code": dmet.s25
                }]
                tmeas = []
                tmeas.append({
                            "label": dmet.s26,
                            "value": [
                                {
                                    "label": dmet.s27,
                                    "value": cmeas
                                }
                            ]
                        })
                newMet = {
                    "label": "SurveyCode",
                    "metrics": tmeas
                }
                mets.append(newMet)

                if ([z for z in db_result["diversitymeasure"] if z["label"] == "genderRep"]):
                    genderData = [z for z in db_result["diversitymeasure"] if z["label"] == "genderRep"][0]
                    if ([a for a in genderData["metrics"] if a["label"] == dmet.s26]):
                        yearData = [aa for aa in genderData["metrics"] if aa["label"] == dmet.s26][0]
                        if ([bb for bb in yearData["value"] if bb["label"] == dmet.s27]):
                            # check sex n race
                            if ([z for z in db_result["diversitymeasure"] if z["label"] == "sexRep"]):
                                sexData = [z for z in db_result["diversitymeasure"] if z["label"] == "sexRep"][0]
                                if ([a for a in sexData["metrics"] if a["label"] == dmet.s26]):
                                    yearDataS = [aa for aa in sexData["metrics"] if aa["label"] == dmet.s26][0]
                                    if ([bb for bb in yearDataS["value"] if bb["label"] == dmet.s27]):
                                        if ([z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"]):
                                            raceData = [z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"][0]
                                            if ([a for a in raceData["metrics"] if a["label"] == dmet.s26]):
                                                yearDataR = [aa for aa in raceData["metrics"] if aa["label"] == dmet.s26][0]
                                                if ([bb for bb in yearDataR["value"] if bb["label"] == dmet.s27]):
                                                    pass
                                                else:
                                                    newMetR = {
                                                        "label": "raceRep",
                                                        "metrics": [
                                                            {
                                                                "label": dmet.s26,
                                                                "value": [
                                                                    {
                                                                        "label": dmet.s27,
                                                                        "value": [
                                                                            {
                                                                                "asianCSuite": 0,
                                                                                "hawaiianCSuite": 0,
                                                                                "blackCSuite": 0,
                                                                                "hispanicCSuite": 0,
                                                                                "nativeCSuite": 0,
                                                                                "whiteCSuite": 0,
                                                                                "multiCSuite": 0,
                                                                                "preferCSuite": 0,
                                                                                "asianEmployees": 0,
                                                                                "hawaiianEmployees": 0,
                                                                                "blackEmployees": 0,
                                                                                "hispanicEmployees": 0,
                                                                                "nativeEmployees": 0,
                                                                                "whiteEmployees": 0,
                                                                                "multiEmployees": 0,
                                                                                "preferEmployees": 0,
                                                                                "asianBoard": 0,
                                                                                "hawaiianBoard": 0,
                                                                                "blackBoard": 0,
                                                                                "hispanicBoard": 0,
                                                                                "nativeBoard": 0,
                                                                                "whiteBoard": 0,
                                                                                "multiBoard": 0,
                                                                                "preferBoard": 0
                                                                            }
                                                                        ]
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                    mets.append(newMetR)
                                            else:
                                                newMetR = {
                                                    "label": "raceRep",
                                                    "metrics": [
                                                        {
                                                            "label": dmet.s26,
                                                            "value": [
                                                                {
                                                                    "label": dmet.s27,
                                                                    "value": [
                                                                        {
                                                                            "asianCSuite": 0,
                                                                            "hawaiianCSuite": 0,
                                                                            "blackCSuite": 0,
                                                                            "hispanicCSuite": 0,
                                                                            "nativeCSuite": 0,
                                                                            "whiteCSuite": 0,
                                                                            "multiCSuite": 0,
                                                                            "preferCSuite": 0,
                                                                            "asianEmployees": 0,
                                                                            "hawaiianEmployees": 0,
                                                                            "blackEmployees": 0,
                                                                            "hispanicEmployees": 0,
                                                                            "nativeEmployees": 0,
                                                                            "whiteEmployees": 0,
                                                                            "multiEmployees": 0,
                                                                            "preferEmployees": 0,
                                                                            "asianBoard": 0,
                                                                            "hawaiianBoard": 0,
                                                                            "blackBoard": 0,
                                                                            "hispanicBoard": 0,
                                                                            "nativeBoard": 0,
                                                                            "whiteBoard": 0,
                                                                            "multiBoard": 0,
                                                                            "preferBoard": 0
                                                                        }
                                                                    ]
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                                mets.append(newMetR)
                                        else:
                                            newMetR = {
                                                "label": "raceRep",
                                                "metrics": [
                                                    {
                                                        "label": dmet.s26,
                                                        "value": [
                                                            {
                                                                "label": dmet.s27,
                                                                "value": [
                                                                    {
                                                                        "asianCSuite": 0,
                                                                        "hawaiianCSuite": 0,
                                                                        "blackCSuite": 0,
                                                                        "hispanicCSuite": 0,
                                                                        "nativeCSuite": 0,
                                                                        "whiteCSuite": 0,
                                                                        "multiCSuite": 0,
                                                                        "preferCSuite": 0,
                                                                        "asianEmployees": 0,
                                                                        "hawaiianEmployees": 0,
                                                                        "blackEmployees": 0,
                                                                        "hispanicEmployees": 0,
                                                                        "nativeEmployees": 0,
                                                                        "whiteEmployees": 0,
                                                                        "multiEmployees": 0,
                                                                        "preferEmployees": 0,
                                                                        "asianBoard": 0,
                                                                        "hawaiianBoard": 0,
                                                                        "blackBoard": 0,
                                                                        "hispanicBoard": 0,
                                                                        "nativeBoard": 0,
                                                                        "whiteBoard": 0,
                                                                        "multiBoard": 0,
                                                                        "preferBoard": 0
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                            mets.append(newMetR)
                                    else:
                                        newMetS = {
                                            "label": "sexRep",
                                            "metrics": [
                                                {
                                                    "label": dmet.s26,
                                                    "value": [
                                                        {
                                                            "label": dmet.s27,
                                                            "value": [
                                                                {
                                                                    "heteroCSuite": 0,
                                                                    "homoCSuite": 0,
                                                                    "biCSuite": 0,
                                                                    "preferCSuite": 0,
                                                                    "heteroEmployees": 0,
                                                                    "homoEmployees": 0,
                                                                    "biEmployees": 0,
                                                                    "preferEmployees": 0,
                                                                    "heteroBoard": 0,
                                                                    "homoBoard": 0,
                                                                    "biBoard": 0,
                                                                    "preferBoard": 0
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                        mets.append(newMetS)
                                        if ([z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"]):
                                            raceData = [z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"][0]
                                            if ([a for a in raceData["metrics"] if a["label"] == dmet.s26]):
                                                yearDataR = [aa for aa in raceData["metrics"] if aa["label"] == dmet.s26][0]
                                                if ([bb for bb in yearDataR["value"] if bb["label"] == dmet.s27]):
                                                    pass
                                                else:
                                                    newMetR = {
                                                        "label": "raceRep",
                                                        "metrics": [
                                                            {
                                                                "label": dmet.s26,
                                                                "value": [
                                                                    {
                                                                        "label": dmet.s27,
                                                                        "value": [
                                                                            {
                                                                                "asianCSuite": 0,
                                                                                "hawaiianCSuite": 0,
                                                                                "blackCSuite": 0,
                                                                                "hispanicCSuite": 0,
                                                                                "nativeCSuite": 0,
                                                                                "whiteCSuite": 0,
                                                                                "multiCSuite": 0,
                                                                                "preferCSuite": 0,
                                                                                "asianEmployees": 0,
                                                                                "hawaiianEmployees": 0,
                                                                                "blackEmployees": 0,
                                                                                "hispanicEmployees": 0,
                                                                                "nativeEmployees": 0,
                                                                                "whiteEmployees": 0,
                                                                                "multiEmployees": 0,
                                                                                "preferEmployees": 0,
                                                                                "asianBoard": 0,
                                                                                "hawaiianBoard": 0,
                                                                                "blackBoard": 0,
                                                                                "hispanicBoard": 0,
                                                                                "nativeBoard": 0,
                                                                                "whiteBoard": 0,
                                                                                "multiBoard": 0,
                                                                                "preferBoard": 0
                                                                            }
                                                                        ]
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                    mets.append(newMetR)
                                            else:
                                                newMetR = {
                                                    "label": "raceRep",
                                                    "metrics": [
                                                        {
                                                            "label": dmet.s26,
                                                            "value": [
                                                                {
                                                                    "label": dmet.s27,
                                                                    "value": [
                                                                        {
                                                                            "asianCSuite": 0,
                                                                            "hawaiianCSuite": 0,
                                                                            "blackCSuite": 0,
                                                                            "hispanicCSuite": 0,
                                                                            "nativeCSuite": 0,
                                                                            "whiteCSuite": 0,
                                                                            "multiCSuite": 0,
                                                                            "preferCSuite": 0,
                                                                            "asianEmployees": 0,
                                                                            "hawaiianEmployees": 0,
                                                                            "blackEmployees": 0,
                                                                            "hispanicEmployees": 0,
                                                                            "nativeEmployees": 0,
                                                                            "whiteEmployees": 0,
                                                                            "multiEmployees": 0,
                                                                            "preferEmployees": 0,
                                                                            "asianBoard": 0,
                                                                            "hawaiianBoard": 0,
                                                                            "blackBoard": 0,
                                                                            "hispanicBoard": 0,
                                                                            "nativeBoard": 0,
                                                                            "whiteBoard": 0,
                                                                            "multiBoard": 0,
                                                                            "preferBoard": 0
                                                                        }
                                                                    ]
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                                mets.append(newMetR)
                                        else:
                                            newMetR = {
                                                "label": "raceRep",
                                                "metrics": [
                                                    {
                                                        "label": dmet.s26,
                                                        "value": [
                                                            {
                                                                "label": dmet.s27,
                                                                "value": [
                                                                    {
                                                                        "asianCSuite": 0,
                                                                        "hawaiianCSuite": 0,
                                                                        "blackCSuite": 0,
                                                                        "hispanicCSuite": 0,
                                                                        "nativeCSuite": 0,
                                                                        "whiteCSuite": 0,
                                                                        "multiCSuite": 0,
                                                                        "preferCSuite": 0,
                                                                        "asianEmployees": 0,
                                                                        "hawaiianEmployees": 0,
                                                                        "blackEmployees": 0,
                                                                        "hispanicEmployees": 0,
                                                                        "nativeEmployees": 0,
                                                                        "whiteEmployees": 0,
                                                                        "multiEmployees": 0,
                                                                        "preferEmployees": 0,
                                                                        "asianBoard": 0,
                                                                        "hawaiianBoard": 0,
                                                                        "blackBoard": 0,
                                                                        "hispanicBoard": 0,
                                                                        "nativeBoard": 0,
                                                                        "whiteBoard": 0,
                                                                        "multiBoard": 0,
                                                                        "preferBoard": 0
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                            mets.append(newMetR)

                                else:
                                    newMetS = {
                                            "label": "sexRep",
                                            "metrics": [
                                                {
                                                    "label": dmet.s26,
                                                    "value": [
                                                        {
                                                            "label": dmet.s27,
                                                            "value": [
                                                                {
                                                                    "heteroCSuite": 0,
                                                                    "homoCSuite": 0,
                                                                    "biCSuite": 0,
                                                                    "preferCSuite": 0,
                                                                    "heteroEmployees": 0,
                                                                    "homoEmployees": 0,
                                                                    "biEmployees": 0,
                                                                    "preferEmployees": 0,
                                                                    "heteroBoard": 0,
                                                                    "homoBoard": 0,
                                                                    "biBoard": 0,
                                                                    "preferBoard": 0
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                    mets.append(newMetS)
                                    if ([z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"]):
                                        raceData = [z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"][0]
                                        if ([a for a in raceData["metrics"] if a["label"] == dmet.s26]):
                                            yearDataR = [aa for aa in raceData["metrics"] if aa["label"] == dmet.s26][0]
                                            if ([bb for bb in yearDataR["value"] if bb["label"] == dmet.s27]):
                                                pass
                                            else:
                                                newMetR = {
                                                    "label": "raceRep",
                                                    "metrics": [
                                                        {
                                                            "label": dmet.s26,
                                                            "value": [
                                                                {
                                                                    "label": dmet.s27,
                                                                    "value": [
                                                                        {
                                                                            "asianCSuite": 0,
                                                                            "hawaiianCSuite": 0,
                                                                            "blackCSuite": 0,
                                                                            "hispanicCSuite": 0,
                                                                            "nativeCSuite": 0,
                                                                            "whiteCSuite": 0,
                                                                            "multiCSuite": 0,
                                                                            "preferCSuite": 0,
                                                                            "asianEmployees": 0,
                                                                            "hawaiianEmployees": 0,
                                                                            "blackEmployees": 0,
                                                                            "hispanicEmployees": 0,
                                                                            "nativeEmployees": 0,
                                                                            "whiteEmployees": 0,
                                                                            "multiEmployees": 0,
                                                                            "preferEmployees": 0,
                                                                            "asianBoard": 0,
                                                                            "hawaiianBoard": 0,
                                                                            "blackBoard": 0,
                                                                            "hispanicBoard": 0,
                                                                            "nativeBoard": 0,
                                                                            "whiteBoard": 0,
                                                                            "multiBoard": 0,
                                                                            "preferBoard": 0
                                                                        }
                                                                    ]
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                                mets.append(newMetR)
                                        else:
                                            newMetR = {
                                                "label": "raceRep",
                                                "metrics": [
                                                    {
                                                        "label": dmet.s26,
                                                        "value": [
                                                            {
                                                                "label": dmet.s27,
                                                                "value": [
                                                                    {
                                                                        "asianCSuite": 0,
                                                                        "hawaiianCSuite": 0,
                                                                        "blackCSuite": 0,
                                                                        "hispanicCSuite": 0,
                                                                        "nativeCSuite": 0,
                                                                        "whiteCSuite": 0,
                                                                        "multiCSuite": 0,
                                                                        "preferCSuite": 0,
                                                                        "asianEmployees": 0,
                                                                        "hawaiianEmployees": 0,
                                                                        "blackEmployees": 0,
                                                                        "hispanicEmployees": 0,
                                                                        "nativeEmployees": 0,
                                                                        "whiteEmployees": 0,
                                                                        "multiEmployees": 0,
                                                                        "preferEmployees": 0,
                                                                        "asianBoard": 0,
                                                                        "hawaiianBoard": 0,
                                                                        "blackBoard": 0,
                                                                        "hispanicBoard": 0,
                                                                        "nativeBoard": 0,
                                                                        "whiteBoard": 0,
                                                                        "multiBoard": 0,
                                                                        "preferBoard": 0
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                            mets.append(newMetR)
                                    else:
                                        newMetR = {
                                            "label": "raceRep",
                                            "metrics": [
                                                {
                                                    "label": dmet.s26,
                                                    "value": [
                                                        {
                                                            "label": dmet.s27,
                                                            "value": [
                                                                {
                                                                    "asianCSuite": 0,
                                                                    "hawaiianCSuite": 0,
                                                                    "blackCSuite": 0,
                                                                    "hispanicCSuite": 0,
                                                                    "nativeCSuite": 0,
                                                                    "whiteCSuite": 0,
                                                                    "multiCSuite": 0,
                                                                    "preferCSuite": 0,
                                                                    "asianEmployees": 0,
                                                                    "hawaiianEmployees": 0,
                                                                    "blackEmployees": 0,
                                                                    "hispanicEmployees": 0,
                                                                    "nativeEmployees": 0,
                                                                    "whiteEmployees": 0,
                                                                    "multiEmployees": 0,
                                                                    "preferEmployees": 0,
                                                                    "asianBoard": 0,
                                                                    "hawaiianBoard": 0,
                                                                    "blackBoard": 0,
                                                                    "hispanicBoard": 0,
                                                                    "nativeBoard": 0,
                                                                    "whiteBoard": 0,
                                                                    "multiBoard": 0,
                                                                    "preferBoard": 0
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                        mets.append(newMetR)
                            else:
                                newMetS = {
                                            "label": "sexRep",
                                            "metrics": [
                                                {
                                                    "label": dmet.s26,
                                                    "value": [
                                                        {
                                                            "label": dmet.s27,
                                                            "value": [
                                                                {
                                                                    "heteroCSuite": 0,
                                                                    "homoCSuite": 0,
                                                                    "biCSuite": 0,
                                                                    "preferCSuite": 0,
                                                                    "heteroEmployees": 0,
                                                                    "homoEmployees": 0,
                                                                    "biEmployees": 0,
                                                                    "preferEmployees": 0,
                                                                    "heteroBoard": 0,
                                                                    "homoBoard": 0,
                                                                    "biBoard": 0,
                                                                    "preferBoard": 0
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                mets.append(newMetS)
                                if ([z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"]):
                                    raceData = [z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"][0]
                                    if ([a for a in raceData["metrics"] if a["label"] == dmet.s26]):
                                        yearDataR = [aa for aa in raceData["metrics"] if aa["label"] == dmet.s26][0]
                                        if ([bb for bb in yearDataR["value"] if bb["label"] == dmet.s27]):
                                            pass
                                        else:
                                            newMetR = {
                                                "label": "raceRep",
                                                "metrics": [
                                                    {
                                                        "label": dmet.s26,
                                                        "value": [
                                                            {
                                                                "label": dmet.s27,
                                                                "value": [
                                                                    {
                                                                        "asianCSuite": 0,
                                                                        "hawaiianCSuite": 0,
                                                                        "blackCSuite": 0,
                                                                        "hispanicCSuite": 0,
                                                                        "nativeCSuite": 0,
                                                                        "whiteCSuite": 0,
                                                                        "multiCSuite": 0,
                                                                        "preferCSuite": 0,
                                                                        "asianEmployees": 0,
                                                                        "hawaiianEmployees": 0,
                                                                        "blackEmployees": 0,
                                                                        "hispanicEmployees": 0,
                                                                        "nativeEmployees": 0,
                                                                        "whiteEmployees": 0,
                                                                        "multiEmployees": 0,
                                                                        "preferEmployees": 0,
                                                                        "asianBoard": 0,
                                                                        "hawaiianBoard": 0,
                                                                        "blackBoard": 0,
                                                                        "hispanicBoard": 0,
                                                                        "nativeBoard": 0,
                                                                        "whiteBoard": 0,
                                                                        "multiBoard": 0,
                                                                        "preferBoard": 0
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                            mets.append(newMetR)
                                    else:
                                        newMetR = {
                                            "label": "raceRep",
                                            "metrics": [
                                                {
                                                    "label": dmet.s26,
                                                    "value": [
                                                        {
                                                            "label": dmet.s27,
                                                            "value": [
                                                                {
                                                                    "asianCSuite": 0,
                                                                    "hawaiianCSuite": 0,
                                                                    "blackCSuite": 0,
                                                                    "hispanicCSuite": 0,
                                                                    "nativeCSuite": 0,
                                                                    "whiteCSuite": 0,
                                                                    "multiCSuite": 0,
                                                                    "preferCSuite": 0,
                                                                    "asianEmployees": 0,
                                                                    "hawaiianEmployees": 0,
                                                                    "blackEmployees": 0,
                                                                    "hispanicEmployees": 0,
                                                                    "nativeEmployees": 0,
                                                                    "whiteEmployees": 0,
                                                                    "multiEmployees": 0,
                                                                    "preferEmployees": 0,
                                                                    "asianBoard": 0,
                                                                    "hawaiianBoard": 0,
                                                                    "blackBoard": 0,
                                                                    "hispanicBoard": 0,
                                                                    "nativeBoard": 0,
                                                                    "whiteBoard": 0,
                                                                    "multiBoard": 0,
                                                                    "preferBoard": 0
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                        mets.append(newMetR)
                                else:
                                    newMetR = {
                                        "label": "raceRep",
                                        "metrics": [
                                            {
                                                "label": dmet.s26,
                                                "value": [
                                                    {
                                                        "label": dmet.s27,
                                                        "value": [
                                                            {
                                                                "asianCSuite": 0,
                                                                "hawaiianCSuite": 0,
                                                                "blackCSuite": 0,
                                                                "hispanicCSuite": 0,
                                                                "nativeCSuite": 0,
                                                                "whiteCSuite": 0,
                                                                "multiCSuite": 0,
                                                                "preferCSuite": 0,
                                                                "asianEmployees": 0,
                                                                "hawaiianEmployees": 0,
                                                                "blackEmployees": 0,
                                                                "hispanicEmployees": 0,
                                                                "nativeEmployees": 0,
                                                                "whiteEmployees": 0,
                                                                "multiEmployees": 0,
                                                                "preferEmployees": 0,
                                                                "asianBoard": 0,
                                                                "hawaiianBoard": 0,
                                                                "blackBoard": 0,
                                                                "hispanicBoard": 0,
                                                                "nativeBoard": 0,
                                                                "whiteBoard": 0,
                                                                "multiBoard": 0,
                                                                "preferBoard": 0
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                        ]
                                    }
                                    mets.append(newMetR)
                        else:
                            newMetG = {
                            "label": "genderRep",
                            "metrics": [
                                {
                                    "label": dmet.s26,
                                    "value": [
                                        {
                                        "label": dmet.s27,
                                        "value": [
                                            {
                                            "maleCSuite": dmet.s1,
                                            "femaleCSuite": dmet.s2,
                                            "genderCSuite": dmet.s3,
                                            "transCSuite": dmet.s4,
                                            "preferCSuite": dmet.s5,
                                            "maleEmployees": dmet.s6,
                                            "femaleEmployees": dmet.s7,
                                            "genderEmployees": dmet.s8,
                                            "transEmployees": dmet.s9,
                                            "preferEmployees": dmet.s10,
                                            "maleBoard": dmet.s11,
                                            "femaleBoard": dmet.s12,
                                            "genderBoard": dmet.s13,
                                            "transBoard": dmet.s14,
                                            "preferBoard": dmet.s15
                                        }
                                        ]
                                        }
                                    ]
                                }
                            ]
                            }
                            mets.append(newMetG)
                            if ([z for z in db_result["diversitymeasure"] if z["label"] == "sexRep"]):
                                sexData = [z for z in db_result["diversitymeasure"] if z["label"] == "sexRep"][0]
                                if ([a for a in sexData["metrics"] if a["label"] == dmet.s26]):
                                    yearDataS = [aa for aa in sexData["metrics"] if aa["label"] == dmet.s26][0]
                                    if ([bb for bb in yearDataS["value"] if bb["label"] == dmet.s27]):
                                        if ([z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"]):
                                            raceData = [z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"][0]
                                            if ([a for a in raceData["metrics"] if a["label"] == dmet.s26]):
                                                yearDataR = [aa for aa in raceData["metrics"] if aa["label"] == dmet.s26][0]
                                                if ([bb for bb in yearDataR["value"] if bb["label"] == dmet.s27]):
                                                    pass
                                                else:
                                                    newMetR = {
                                                        "label": "raceRep",
                                                        "metrics": [
                                                            {
                                                                "label": dmet.s26,
                                                                "value": [
                                                                    {
                                                                        "label": dmet.s27,
                                                                        "value": [
                                                                            {
                                                                                "asianCSuite": 0,
                                                                                "hawaiianCSuite": 0,
                                                                                "blackCSuite": 0,
                                                                                "hispanicCSuite": 0,
                                                                                "nativeCSuite": 0,
                                                                                "whiteCSuite": 0,
                                                                                "multiCSuite": 0,
                                                                                "preferCSuite": 0,
                                                                                "asianEmployees": 0,
                                                                                "hawaiianEmployees": 0,
                                                                                "blackEmployees": 0,
                                                                                "hispanicEmployees": 0,
                                                                                "nativeEmployees": 0,
                                                                                "whiteEmployees": 0,
                                                                                "multiEmployees": 0,
                                                                                "preferEmployees": 0,
                                                                                "asianBoard": 0,
                                                                                "hawaiianBoard": 0,
                                                                                "blackBoard": 0,
                                                                                "hispanicBoard": 0,
                                                                                "nativeBoard": 0,
                                                                                "whiteBoard": 0,
                                                                                "multiBoard": 0,
                                                                                "preferBoard": 0
                                                                            }
                                                                        ]
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                    mets.append(newMetR)
                                            else:
                                                newMetR = {
                                                    "label": "raceRep",
                                                    "metrics": [
                                                        {
                                                            "label": dmet.s26,
                                                            "value": [
                                                                {
                                                                    "label": dmet.s27,
                                                                    "value": [
                                                                        {
                                                                            "asianCSuite": 0,
                                                                            "hawaiianCSuite": 0,
                                                                            "blackCSuite": 0,
                                                                            "hispanicCSuite": 0,
                                                                            "nativeCSuite": 0,
                                                                            "whiteCSuite": 0,
                                                                            "multiCSuite": 0,
                                                                            "preferCSuite": 0,
                                                                            "asianEmployees": 0,
                                                                            "hawaiianEmployees": 0,
                                                                            "blackEmployees": 0,
                                                                            "hispanicEmployees": 0,
                                                                            "nativeEmployees": 0,
                                                                            "whiteEmployees": 0,
                                                                            "multiEmployees": 0,
                                                                            "preferEmployees": 0,
                                                                            "asianBoard": 0,
                                                                            "hawaiianBoard": 0,
                                                                            "blackBoard": 0,
                                                                            "hispanicBoard": 0,
                                                                            "nativeBoard": 0,
                                                                            "whiteBoard": 0,
                                                                            "multiBoard": 0,
                                                                            "preferBoard": 0
                                                                        }
                                                                    ]
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                                mets.append(newMetR)
                                        else:
                                            newMetR = {
                                                "label": "raceRep",
                                                "metrics": [
                                                    {
                                                        "label": dmet.s26,
                                                        "value": [
                                                            {
                                                                "label": dmet.s27,
                                                                "value": [
                                                                    {
                                                                        "asianCSuite": 0,
                                                                        "hawaiianCSuite": 0,
                                                                        "blackCSuite": 0,
                                                                        "hispanicCSuite": 0,
                                                                        "nativeCSuite": 0,
                                                                        "whiteCSuite": 0,
                                                                        "multiCSuite": 0,
                                                                        "preferCSuite": 0,
                                                                        "asianEmployees": 0,
                                                                        "hawaiianEmployees": 0,
                                                                        "blackEmployees": 0,
                                                                        "hispanicEmployees": 0,
                                                                        "nativeEmployees": 0,
                                                                        "whiteEmployees": 0,
                                                                        "multiEmployees": 0,
                                                                        "preferEmployees": 0,
                                                                        "asianBoard": 0,
                                                                        "hawaiianBoard": 0,
                                                                        "blackBoard": 0,
                                                                        "hispanicBoard": 0,
                                                                        "nativeBoard": 0,
                                                                        "whiteBoard": 0,
                                                                        "multiBoard": 0,
                                                                        "preferBoard": 0
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                            mets.append(newMetR)
                                    else:
                                        newMetS = {
                                            "label": "sexRep",
                                            "metrics": [
                                                {
                                                    "label": dmet.s26,
                                                    "value": [
                                                        {
                                                            "label": dmet.s27,
                                                            "value": [
                                                                {
                                                                    "heteroCSuite": 0,
                                                                    "homoCSuite": 0,
                                                                    "biCSuite": 0,
                                                                    "preferCSuite": 0,
                                                                    "heteroEmployees": 0,
                                                                    "homoEmployees": 0,
                                                                    "biEmployees": 0,
                                                                    "preferEmployees": 0,
                                                                    "heteroBoard": 0,
                                                                    "homoBoard": 0,
                                                                    "biBoard": 0,
                                                                    "preferBoard": 0
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                        mets.append(newMetS)
                                        if ([z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"]):
                                            raceData = [z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"][0]
                                            if ([a for a in raceData["metrics"] if a["label"] == dmet.s26]):
                                                yearDataR = [aa for aa in raceData["metrics"] if aa["label"] == dmet.s26][0]
                                                if ([bb for bb in yearDataR["value"] if bb["label"] == dmet.s27]):
                                                    pass
                                                else:
                                                    newMetR = {
                                                        "label": "raceRep",
                                                        "metrics": [
                                                            {
                                                                "label": dmet.s26,
                                                                "value": [
                                                                    {
                                                                        "label": dmet.s27,
                                                                        "value": [
                                                                            {
                                                                                "asianCSuite": 0,
                                                                                "hawaiianCSuite": 0,
                                                                                "blackCSuite": 0,
                                                                                "hispanicCSuite": 0,
                                                                                "nativeCSuite": 0,
                                                                                "whiteCSuite": 0,
                                                                                "multiCSuite": 0,
                                                                                "preferCSuite": 0,
                                                                                "asianEmployees": 0,
                                                                                "hawaiianEmployees": 0,
                                                                                "blackEmployees": 0,
                                                                                "hispanicEmployees": 0,
                                                                                "nativeEmployees": 0,
                                                                                "whiteEmployees": 0,
                                                                                "multiEmployees": 0,
                                                                                "preferEmployees": 0,
                                                                                "asianBoard": 0,
                                                                                "hawaiianBoard": 0,
                                                                                "blackBoard": 0,
                                                                                "hispanicBoard": 0,
                                                                                "nativeBoard": 0,
                                                                                "whiteBoard": 0,
                                                                                "multiBoard": 0,
                                                                                "preferBoard": 0
                                                                            }
                                                                        ]
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                    mets.append(newMetR)
                                            else:
                                                newMetR = {
                                                    "label": "raceRep",
                                                    "metrics": [
                                                        {
                                                            "label": dmet.s26,
                                                            "value": [
                                                                {
                                                                    "label": dmet.s27,
                                                                    "value": [
                                                                        {
                                                                            "asianCSuite": 0,
                                                                            "hawaiianCSuite": 0,
                                                                            "blackCSuite": 0,
                                                                            "hispanicCSuite": 0,
                                                                            "nativeCSuite": 0,
                                                                            "whiteCSuite": 0,
                                                                            "multiCSuite": 0,
                                                                            "preferCSuite": 0,
                                                                            "asianEmployees": 0,
                                                                            "hawaiianEmployees": 0,
                                                                            "blackEmployees": 0,
                                                                            "hispanicEmployees": 0,
                                                                            "nativeEmployees": 0,
                                                                            "whiteEmployees": 0,
                                                                            "multiEmployees": 0,
                                                                            "preferEmployees": 0,
                                                                            "asianBoard": 0,
                                                                            "hawaiianBoard": 0,
                                                                            "blackBoard": 0,
                                                                            "hispanicBoard": 0,
                                                                            "nativeBoard": 0,
                                                                            "whiteBoard": 0,
                                                                            "multiBoard": 0,
                                                                            "preferBoard": 0
                                                                        }
                                                                    ]
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                                mets.append(newMetR)
                                        else:
                                            newMetR = {
                                                "label": "raceRep",
                                                "metrics": [
                                                    {
                                                        "label": dmet.s26,
                                                        "value": [
                                                            {
                                                                "label": dmet.s27,
                                                                "value": [
                                                                    {
                                                                        "asianCSuite": 0,
                                                                        "hawaiianCSuite": 0,
                                                                        "blackCSuite": 0,
                                                                        "hispanicCSuite": 0,
                                                                        "nativeCSuite": 0,
                                                                        "whiteCSuite": 0,
                                                                        "multiCSuite": 0,
                                                                        "preferCSuite": 0,
                                                                        "asianEmployees": 0,
                                                                        "hawaiianEmployees": 0,
                                                                        "blackEmployees": 0,
                                                                        "hispanicEmployees": 0,
                                                                        "nativeEmployees": 0,
                                                                        "whiteEmployees": 0,
                                                                        "multiEmployees": 0,
                                                                        "preferEmployees": 0,
                                                                        "asianBoard": 0,
                                                                        "hawaiianBoard": 0,
                                                                        "blackBoard": 0,
                                                                        "hispanicBoard": 0,
                                                                        "nativeBoard": 0,
                                                                        "whiteBoard": 0,
                                                                        "multiBoard": 0,
                                                                        "preferBoard": 0
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                            mets.append(newMetR)

                                else:
                                    newMetS = {
                                            "label": "sexRep",
                                            "metrics": [
                                                {
                                                    "label": dmet.s26,
                                                    "value": [
                                                        {
                                                            "label": dmet.s27,
                                                            "value": [
                                                                {
                                                                    "heteroCSuite": 0,
                                                                    "homoCSuite": 0,
                                                                    "biCSuite": 0,
                                                                    "preferCSuite": 0,
                                                                    "heteroEmployees": 0,
                                                                    "homoEmployees": 0,
                                                                    "biEmployees": 0,
                                                                    "preferEmployees": 0,
                                                                    "heteroBoard": 0,
                                                                    "homoBoard": 0,
                                                                    "biBoard": 0,
                                                                    "preferBoard": 0
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                    mets.append(newMetS)
                                    if ([z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"]):
                                        raceData = [z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"][0]
                                        if ([a for a in raceData["metrics"] if a["label"] == dmet.s26]):
                                            yearDataR = [aa for aa in raceData["metrics"] if aa["label"] == dmet.s26][0]
                                            if ([bb for bb in yearDataR["value"] if bb["label"] == dmet.s27]):
                                                pass
                                            else:
                                                newMetR = {
                                                    "label": "raceRep",
                                                    "metrics": [
                                                        {
                                                            "label": dmet.s26,
                                                            "value": [
                                                                {
                                                                    "label": dmet.s27,
                                                                    "value": [
                                                                        {
                                                                            "asianCSuite": 0,
                                                                            "hawaiianCSuite": 0,
                                                                            "blackCSuite": 0,
                                                                            "hispanicCSuite": 0,
                                                                            "nativeCSuite": 0,
                                                                            "whiteCSuite": 0,
                                                                            "multiCSuite": 0,
                                                                            "preferCSuite": 0,
                                                                            "asianEmployees": 0,
                                                                            "hawaiianEmployees": 0,
                                                                            "blackEmployees": 0,
                                                                            "hispanicEmployees": 0,
                                                                            "nativeEmployees": 0,
                                                                            "whiteEmployees": 0,
                                                                            "multiEmployees": 0,
                                                                            "preferEmployees": 0,
                                                                            "asianBoard": 0,
                                                                            "hawaiianBoard": 0,
                                                                            "blackBoard": 0,
                                                                            "hispanicBoard": 0,
                                                                            "nativeBoard": 0,
                                                                            "whiteBoard": 0,
                                                                            "multiBoard": 0,
                                                                            "preferBoard": 0
                                                                        }
                                                                    ]
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                                mets.append(newMetR)
                                        else:
                                            newMetR = {
                                                "label": "raceRep",
                                                "metrics": [
                                                    {
                                                        "label": dmet.s26,
                                                        "value": [
                                                            {
                                                                "label": dmet.s27,
                                                                "value": [
                                                                    {
                                                                        "asianCSuite": 0,
                                                                        "hawaiianCSuite": 0,
                                                                        "blackCSuite": 0,
                                                                        "hispanicCSuite": 0,
                                                                        "nativeCSuite": 0,
                                                                        "whiteCSuite": 0,
                                                                        "multiCSuite": 0,
                                                                        "preferCSuite": 0,
                                                                        "asianEmployees": 0,
                                                                        "hawaiianEmployees": 0,
                                                                        "blackEmployees": 0,
                                                                        "hispanicEmployees": 0,
                                                                        "nativeEmployees": 0,
                                                                        "whiteEmployees": 0,
                                                                        "multiEmployees": 0,
                                                                        "preferEmployees": 0,
                                                                        "asianBoard": 0,
                                                                        "hawaiianBoard": 0,
                                                                        "blackBoard": 0,
                                                                        "hispanicBoard": 0,
                                                                        "nativeBoard": 0,
                                                                        "whiteBoard": 0,
                                                                        "multiBoard": 0,
                                                                        "preferBoard": 0
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                            mets.append(newMetR)
                                    else:
                                        newMetR = {
                                            "label": "raceRep",
                                            "metrics": [
                                                {
                                                    "label": dmet.s26,
                                                    "value": [
                                                        {
                                                            "label": dmet.s27,
                                                            "value": [
                                                                {
                                                                    "asianCSuite": 0,
                                                                    "hawaiianCSuite": 0,
                                                                    "blackCSuite": 0,
                                                                    "hispanicCSuite": 0,
                                                                    "nativeCSuite": 0,
                                                                    "whiteCSuite": 0,
                                                                    "multiCSuite": 0,
                                                                    "preferCSuite": 0,
                                                                    "asianEmployees": 0,
                                                                    "hawaiianEmployees": 0,
                                                                    "blackEmployees": 0,
                                                                    "hispanicEmployees": 0,
                                                                    "nativeEmployees": 0,
                                                                    "whiteEmployees": 0,
                                                                    "multiEmployees": 0,
                                                                    "preferEmployees": 0,
                                                                    "asianBoard": 0,
                                                                    "hawaiianBoard": 0,
                                                                    "blackBoard": 0,
                                                                    "hispanicBoard": 0,
                                                                    "nativeBoard": 0,
                                                                    "whiteBoard": 0,
                                                                    "multiBoard": 0,
                                                                    "preferBoard": 0
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                        mets.append(newMetR)
                            else:
                                newMetS = {
                                    "label": "sexRep",
                                    "metrics": [
                                        {
                                            "label": dmet.s26,
                                            "value": [
                                                {
                                                    "label": dmet.s27,
                                                    "value": [
                                                        {
                                                            "heteroCSuite": 0,
                                                            "homoCSuite": 0,
                                                            "biCSuite": 0,
                                                            "preferCSuite": 0,
                                                            "heteroEmployees": 0,
                                                            "homoEmployees": 0,
                                                            "biEmployees": 0,
                                                            "preferEmployees": 0,
                                                            "heteroBoard": 0,
                                                            "homoBoard": 0,
                                                            "biBoard": 0,
                                                            "preferBoard": 0
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                                mets.append(newMetS)
                                if ([z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"]):
                                    raceData = [z for z in db_result["diversitymeasure"] if z["label"] == "raceRep"][0]
                                    if ([a for a in raceData["metrics"] if a["label"] == dmet.s26]):
                                        yearDataR = [aa for aa in raceData["metrics"] if aa["label"] == dmet.s26][0]
                                        if ([bb for bb in yearDataR["value"] if bb["label"] == dmet.s27]):
                                            pass
                                        else:
                                            newMetR = {
                                                "label": "raceRep",
                                                "metrics": [
                                                    {
                                                        "label": dmet.s26,
                                                        "value": [
                                                            {
                                                                "label": dmet.s27,
                                                                "value": [
                                                                    {
                                                                        "asianCSuite": 0,
                                                                        "hawaiianCSuite": 0,
                                                                        "blackCSuite": 0,
                                                                        "hispanicCSuite": 0,
                                                                        "nativeCSuite": 0,
                                                                        "whiteCSuite": 0,
                                                                        "multiCSuite": 0,
                                                                        "preferCSuite": 0,
                                                                        "asianEmployees": 0,
                                                                        "hawaiianEmployees": 0,
                                                                        "blackEmployees": 0,
                                                                        "hispanicEmployees": 0,
                                                                        "nativeEmployees": 0,
                                                                        "whiteEmployees": 0,
                                                                        "multiEmployees": 0,
                                                                        "preferEmployees": 0,
                                                                        "asianBoard": 0,
                                                                        "hawaiianBoard": 0,
                                                                        "blackBoard": 0,
                                                                        "hispanicBoard": 0,
                                                                        "nativeBoard": 0,
                                                                        "whiteBoard": 0,
                                                                        "multiBoard": 0,
                                                                        "preferBoard": 0
                                                                    }
                                                                ]
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                            mets.append(newMetR)
                                    else:
                                        newMetR = {
                                            "label": "raceRep",
                                            "metrics": [
                                                {
                                                    "label": dmet.s26,
                                                    "value": [
                                                        {
                                                            "label": dmet.s27,
                                                            "value": [
                                                                {
                                                                    "asianCSuite": 0,
                                                                    "hawaiianCSuite": 0,
                                                                    "blackCSuite": 0,
                                                                    "hispanicCSuite": 0,
                                                                    "nativeCSuite": 0,
                                                                    "whiteCSuite": 0,
                                                                    "multiCSuite": 0,
                                                                    "preferCSuite": 0,
                                                                    "asianEmployees": 0,
                                                                    "hawaiianEmployees": 0,
                                                                    "blackEmployees": 0,
                                                                    "hispanicEmployees": 0,
                                                                    "nativeEmployees": 0,
                                                                    "whiteEmployees": 0,
                                                                    "multiEmployees": 0,
                                                                    "preferEmployees": 0,
                                                                    "asianBoard": 0,
                                                                    "hawaiianBoard": 0,
                                                                    "blackBoard": 0,
                                                                    "hispanicBoard": 0,
                                                                    "nativeBoard": 0,
                                                                    "whiteBoard": 0,
                                                                    "multiBoard": 0,
                                                                    "preferBoard": 0
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                        mets.append(newMetR)
                                else:
                                    newMetR = {
                                        "label": "raceRep",
                                        "metrics": [
                                            {
                                                "label": dmet.s26,
                                                "value": [
                                                    {
                                                        "label": dmet.s27,
                                                        "value": [
                                                            {
                                                                "asianCSuite": 0,
                                                                "hawaiianCSuite": 0,
                                                                "blackCSuite": 0,
                                                                "hispanicCSuite": 0,
                                                                "nativeCSuite": 0,
                                                                "whiteCSuite": 0,
                                                                "multiCSuite": 0,
                                                                "preferCSuite": 0,
                                                                "asianEmployees": 0,
                                                                "hawaiianEmployees": 0,
                                                                "blackEmployees": 0,
                                                                "hispanicEmployees": 0,
                                                                "nativeEmployees": 0,
                                                                "whiteEmployees": 0,
                                                                "multiEmployees": 0,
                                                                "preferEmployees": 0,
                                                                "asianBoard": 0,
                                                                "hawaiianBoard": 0,
                                                                "blackBoard": 0,
                                                                "hispanicBoard": 0,
                                                                "nativeBoard": 0,
                                                                "whiteBoard": 0,
                                                                "multiBoard": 0,
                                                                "preferBoard": 0
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                        ]
                                    }
                                    mets.append(newMetR)
                    else:
                        newMetG = {
                            "label": "genderRep",
                            "metrics": [
                                {
                                    "label": dmet.s26,
                                    "value": [
                                        {
                                        "label": dmet.s27,
                                        "value": [
                                            {
                                            "maleCSuite": dmet.s1,
                                            "femaleCSuite": dmet.s2,
                                            "genderCSuite": dmet.s3,
                                            "transCSuite": dmet.s4,
                                            "preferCSuite": dmet.s5,
                                            "maleEmployees": dmet.s6,
                                            "femaleEmployees": dmet.s7,
                                            "genderEmployees": dmet.s8,
                                            "transEmployees": dmet.s9,
                                            "preferEmployees": dmet.s10,
                                            "maleBoard": dmet.s11,
                                            "femaleBoard": dmet.s12,
                                            "genderBoard": dmet.s13,
                                            "transBoard": dmet.s14,
                                            "preferBoard": dmet.s15
                                        }
                                        ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets.append(newMetG)
                        newMetS = {
                            "label": "sexRep",
                            "metrics": [
                                {
                                    "label": dmet.s26,
                                    "value": [
                                        {
                                            "label": dmet.s27,
                                            "value": [
                                                {
                                                    "heteroCSuite": 0,
                                                    "homoCSuite": 0,
                                                    "biCSuite": 0,
                                                    "preferCSuite": 0,
                                                    "heteroEmployees": 0,
                                                    "homoEmployees": 0,
                                                    "biEmployees": 0,
                                                    "preferEmployees": 0,
                                                    "heteroBoard": 0,
                                                    "homoBoard": 0,
                                                    "biBoard": 0,
                                                    "preferBoard": 0
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets.append(newMetS)
                        newMetR = {
                            "label": "raceRep",
                            "metrics": [
                                {
                                    "label": dmet.s26,
                                    "value": [
                                        {
                                            "label": dmet.s27,
                                            "value": [
                                                {
                                                    "asianCSuite": 0,
                                                    "hawaiianCSuite": 0,
                                                    "blackCSuite": 0,
                                                    "hispanicCSuite": 0,
                                                    "nativeCSuite": 0,
                                                    "whiteCSuite": 0,
                                                    "multiCSuite": 0,
                                                    "preferCSuite": 0,
                                                    "asianEmployees": 0,
                                                    "hawaiianEmployees": 0,
                                                    "blackEmployees": 0,
                                                    "hispanicEmployees": 0,
                                                    "nativeEmployees": 0,
                                                    "whiteEmployees": 0,
                                                    "multiEmployees": 0,
                                                    "preferEmployees": 0,
                                                    "asianBoard": 0,
                                                    "hawaiianBoard": 0,
                                                    "blackBoard": 0,
                                                    "hispanicBoard": 0,
                                                    "nativeBoard": 0,
                                                    "whiteBoard": 0,
                                                    "multiBoard": 0,
                                                    "preferBoard": 0
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets.append(newMetR)
                else:
                    newMetG = {
                    "label": "genderRep",
                    "metrics": [
                        {
                            "label": dmet.s26,
                            "value": [
                                {
                                "label": dmet.s27,
                                "value": [
                                    {
                                    "maleCSuite": dmet.s1,
                                    "femaleCSuite": dmet.s2,
                                    "genderCSuite": dmet.s3,
                                    "transCSuite": dmet.s4,
                                    "preferCSuite": dmet.s5,
                                    "maleEmployees": dmet.s6,
                                    "femaleEmployees": dmet.s7,
                                    "genderEmployees": dmet.s8,
                                    "transEmployees": dmet.s9,
                                    "preferEmployees": dmet.s10,
                                    "maleBoard": dmet.s11,
                                    "femaleBoard": dmet.s12,
                                    "genderBoard": dmet.s13,
                                    "transBoard": dmet.s14,
                                    "preferBoard": dmet.s15
                                }
                                ]
                                }
                            ]
                        }
                    ]
                    }
                    mets.append(newMetG)
                    newMetS = {
                        "label": "sexRep",
                        "metrics": [
                            {
                                "label": dmet.s26,
                                "value": [
                                    {
                                        "label": dmet.s27,
                                        "value": [
                                            {
                                                "heteroCSuite": 0,
                                                "homoCSuite": 0,
                                                "biCSuite": 0,
                                                "preferCSuite": 0,
                                                "heteroEmployees": 0,
                                                "homoEmployees": 0,
                                                "biEmployees": 0,
                                                "preferEmployees": 0,
                                                "heteroBoard": 0,
                                                "homoBoard": 0,
                                                "biBoard": 0,
                                                "preferBoard": 0
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMetS)
                    newMetR = {
                        "label": "raceRep",
                        "metrics": [
                            {
                                "label": dmet.s26,
                                "value": [
                                    {
                                        "label": dmet.s27,
                                        "value": [
                                            {
                                                "asianCSuite": 0,
                                                "hawaiianCSuite": 0,
                                                "blackCSuite": 0,
                                                "hispanicCSuite": 0,
                                                "nativeCSuite": 0,
                                                "whiteCSuite": 0,
                                                "multiCSuite": 0,
                                                "preferCSuite": 0,
                                                "asianEmployees": 0,
                                                "hawaiianEmployees": 0,
                                                "blackEmployees": 0,
                                                "hispanicEmployees": 0,
                                                "nativeEmployees": 0,
                                                "whiteEmployees": 0,
                                                "multiEmployees": 0,
                                                "preferEmployees": 0,
                                                "asianBoard": 0,
                                                "hawaiianBoard": 0,
                                                "blackBoard": 0,
                                                "hispanicBoard": 0,
                                                "nativeBoard": 0,
                                                "whiteBoard": 0,
                                                "multiBoard": 0,
                                                "preferBoard": 0
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMetR)


                target = {
                    "diversitymeasure": mets
                }
                user.update(target)
                callConnect.container8.upsert_item(body=user)
                user2 = {
                    "id": dmet.s25,
                    "surveymeasure": []
                }
                callConnect.container9.upsert_item(body=user2)
        



"""
Endpoint used to update the diversity metric final page.
"""
@diversityroute.post('/divmeasure')
async def div_measure(dmet: DivMeasure):
    try:
        db_result = read_item(callConnect.container8, dmet.oid, dmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /divmeasure container8')
        return {"url": "/", "atype": False}


    if "diversitymeasure" in db_result:
        if dmet.metric == "DMeasure":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "diversitymeasure": []
            }
            mets = [z for z in db_result["diversitymeasure"] if z["label"] != "DMeasure"]
            if ([z for z in db_result["diversitymeasure"] if z["label"] == "DMeasure"]):
                
                cmeas = [{
                    "jobPosting": dmet.m1,
                    "talentPosting": dmet.m2,
                    "removeBias": dmet.m3,
                    "inclusiveInterview": dmet.m4,
                    "twoUnder": dmet.m5,
                    "hostUnconscious": dmet.m6,
                    "other": dmet.m7,
                    "otherTxt": dmet.s1,
                    "VendorsTxt": dmet.s2,
                    "DiversityTxt": dmet.s3
                }]
                newMet = {
                    "label": "DMeasure",
                    "metrics": [
                        {
                            "label": "1",
                            "value": cmeas
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "diversitymeasure": mets
                }
                user.update(target)
                callConnect.container8.upsert_item(body=user)
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "diversitymeasure": []
                }
                mets = [z for z in db_result["diversitymeasure"] if z["label"] != "DMeasure"]
                newMet = {
                    "label": "DMeasure",
                    "metrics": [
                        {
                            "label": "1",
                            "value": [
                                {
                                    "jobPosting": dmet.m1,
                                    "talentPosting": dmet.m2,
                                    "removeBias": dmet.m3,
                                    "inclusiveInterview": dmet.m4,
                                    "twoUnder": dmet.m5,
                                    "hostUnconscious": dmet.m6,
                                    "other": dmet.m7,
                                    "otherTxt": dmet.s1,
                                    "VendorsTxt": dmet.s2,
                                    "DiversityTxt": dmet.s3
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "diversitymeasure": mets
                }
                user.update(target)
                callConnect.container8.upsert_item(body=user)
        if dmet.metric == "DStart":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "diversitymeasure": []
            }
            mets = [z for z in db_result["diversitymeasure"] if z["label"] != "DStart"]
            if ([z for z in db_result["diversitymeasure"] if z["label"] == "DStart"]):
                percentData = [z for z in db_result["diversitymeasure"] if z["label"] == "DStart"][0]

                if ([a for a in percentData["metrics"] if a["label"] == dmet.s4]):
                    yearData = [aa for aa in percentData["metrics"] if aa["label"] == dmet.s4][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != dmet.s5]
                    cmeas = [{
                        "ddirect": dmet.m1,
                        "dsurvey": dmet.m2
                    }]
                    tmeas = [a for a in percentData["metrics"] if a["label"] != dmet.s4]
                    quarterData.append({
                        "label": dmet.s5,
                        "value": cmeas
                    })
                    tmeas.append({
                                "label": dmet.s4,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "DStart",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "diversitymeasure": mets
                    }
                    user.update(target)
                    callConnect.container8.upsert_item(body=user) 
                else:
                    cmeas = [{
                        "ddirect": dmet.m1,
                        "dsurvey": dmet.m2
                    }]
                    tmeas = [a for a in percentData["metrics"] if a["label"] != dmet.s4]
                    tmeas.append({
                                "label": dmet.s4,
                                "value": [
                                    {
                                        "label": dmet.s5,
                                        "value": cmeas
                                    }
                                ]
                            })
                    newMet = {
                        "label": "DStart",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "diversitymeasure": mets
                    }
                    user.update(target)
                    callConnect.container8.upsert_item(body=user)
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "diversitymeasure": []
                }
                mets = [z for z in db_result["diversitymeasure"] if z["label"] != "DStart"]
                newMet = {
                    "label": "DStart",
                    "metrics": [
                        {
                            "label": dmet.s4,
                            "value": [
                                {
                                    "label": dmet.s5,
                                    "value": [
                                        {
                                            "ddirect": dmet.m1,
                                            "dsurvey": dmet.m2
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "diversitymeasure": mets
                }
                user.update(target)
                callConnect.container8.upsert_item(body=user)




"""
Endpoint used to update the survey questions.
"""
@diversityroute.post('/surveymeasure')
async def survey_measure(dmet: SurveyMeasure):
    try:
        db_result = read_item(callConnect.container9, dmet.label, dmet.label)
    except exceptions.CosmosHttpResponseError as e:
        user = {
            "id": dmet.label,
            "surveymeasure": []
        }
        mets = []
        newMet = {
            "label": "GeneralInfo",
            "metrics": [
                {
                    "label": "1",
                    "value": [
                        {
                            "question1": dmet.s1,
                            "question2": dmet.s2,
                            "question3": dmet.s3,
                            "GeneralInfo": dmet.s4
                        }
                    ]
                }
            ]
        }
        mets.append(newMet)
        target = {
            "surveymeasure": mets
        }
        user.update(target)
        callConnect.container9.upsert_item(body=user)
        return


    if "surveymeasure" in db_result:
        if dmet.metric == "GeneralInfo":
            user = {
                "id": db_result["id"],
                "surveymeasure": []
            }
            mets = [z for z in db_result["surveymeasure"] if z["label"] != "GeneralInfo"]
            if ([z for z in db_result["surveymeasure"] if z["label"] == "GeneralInfo"]):
                cmeas = [{
                    "question1": dmet.s1,
                    "question2": dmet.s2,
                    "question3": dmet.s3,
                    "GeneralInfo": dmet.s4
                }]
                newMet = {
                    "label": "GeneralInfo",
                    "metrics": [
                        {
                            "label": "1",
                            "value": cmeas
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "surveymeasure": mets
                }
                user.update(target)
                callConnect.container9.upsert_item(body=user)
            else:
                user = {
                        "id": db_result["id"],
                        "surveymeasure": []
                }
                mets = [z for z in db_result["surveymeasure"] if z["label"] != "GeneralInfo"]
                newMet = {
                    "label": "GeneralInfo",
                    "metrics": [
                        {
                            "label": "1",
                            "value": [
                                {
                                    "question1": dmet.s1,
                                    "question2": dmet.s2,
                                    "question3": dmet.s3,
                                    "GeneralInfo": dmet.s4
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "surveymeasure": mets
                }
                user.update(target)
                callConnect.container9.upsert_item(body=user)
        if dmet.metric == "RaceEthnicity":
            user = {
                "id": db_result["id"],
                "surveymeasure": []
            }
            mets = [z for z in db_result["surveymeasure"] if z["label"] != "RaceEthnicity"]
            if ([z for z in db_result["surveymeasure"] if z["label"] == "RaceEthnicity"]):
                # nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "genderRep"][0]
                
                cmeas = [{
                    "GeneralInfo": dmet.s4
                }]
                newMet = {
                    "label": "RaceEthnicity",
                    "metrics": [
                        {
                            "label": "1",
                            "value": cmeas
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "surveymeasure": mets
                }
                user.update(target)
                callConnect.container9.upsert_item(body=user)
            else:
                user = {
                        "id": db_result["id"],
                        "surveymeasure": []
                }
                mets = [z for z in db_result["surveymeasure"] if z["label"] != "RaceEthnicity"]
                newMet = {
                    "label": "RaceEthnicity",
                    "metrics": [
                        {
                            "label": "1",
                            "value": [
                                {
                                    "GeneralInfo": dmet.s4
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "surveymeasure": mets
                }
                user.update(target)
                callConnect.container9.upsert_item(body=user)
        if dmet.metric == "Gender":
            user = {
                "id": db_result["id"],
                "surveymeasure": []
            }
            mets = [z for z in db_result["surveymeasure"] if z["label"] != "Gender"]
            if ([z for z in db_result["surveymeasure"] if z["label"] == "Gender"]):
                cmeas = [{
                    "GeneralInfo": dmet.s4
                }]
                newMet = {
                    "label": "Gender",
                    "metrics": [
                        {
                            "label": "1",
                            "value": cmeas
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "surveymeasure": mets
                }
                user.update(target)
                callConnect.container9.upsert_item(body=user)
            else:
                user = {
                        "id": db_result["id"],
                        "surveymeasure": []
                }
                mets = [z for z in db_result["surveymeasure"] if z["label"] != "Gender"]
                newMet = {
                    "label": "Gender",
                    "metrics": [
                        {
                            "label": "1",
                            "value": [
                                {
                                    "GeneralInfo": dmet.s4
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "surveymeasure": mets
                }
                user.update(target)
                callConnect.container9.upsert_item(body=user)
        if dmet.metric == "SexualOrientation":
            user = {
                "id": db_result["id"],
                "surveymeasure": []
            }
            mets = [z for z in db_result["surveymeasure"] if z["label"] != "SexualOrientation"]
            if ([z for z in db_result["surveymeasure"] if z["label"] == "SexualOrientation"]):
                cmeas = [{
                    "GeneralInfo": dmet.s4
                }]
                newMet = {
                    "label": "SexualOrientation",
                    "metrics": [
                        {
                            "label": "1",
                            "value": cmeas
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "surveymeasure": mets
                }
                user.update(target)
                callConnect.container9.upsert_item(body=user)
            else:
                user = {
                        "id": db_result["id"],
                        "surveymeasure": []
                }
                mets = [z for z in db_result["surveymeasure"] if z["label"] != "SexualOrientation"]
                newMet = {
                    "label": "SexualOrientation",
                    "metrics": [
                        {
                            "label": "1",
                            "value": [
                                {
                                    "GeneralInfo": dmet.s4
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "surveymeasure": mets
                }
                user.update(target)
                callConnect.container9.upsert_item(body=user)


"""
Endpoint used to update the survey questions.
"""
@diversityroute.post('/submitsurvey')
async def submit_survey(dmet: SubmitSurvey):
    try:
        db_result = read_item(callConnect.container9, dmet.label, dmet.label)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /submitsurvey container9')
        return {"url": "/", "atype": False}


    if "surveymeasure" in db_result:
        user = {
            "id": db_result["id"],
            "surveymeasure": []
        }
        
        mets = [z for z in db_result["surveymeasure"] if z["label"] != "Results"]
        if ([z for z in db_result["surveymeasure"] if z["label"] == "Results"]):
            nmet = [z for z in db_result["surveymeasure"] if z["label"] == "Results"][0]
            if nmet:
                cmeas = [f for f in nmet["metrics"]]
                cmeasNEW = [z for z in cmeas if z["uuid"] != dmet.nano]
                cmeasNEW1 = [z for z in cmeas if z["uuid"] == dmet.nano]
                
                if "results" in cmeasNEW1[0]:
                    res = cmeasNEW1[0]["results"]
                    cmeasNEW2 = [a for a in res if a["label"] != dmet.metric]

                    if dmet.metric == "GeneralInfo":
                        cmeasNEW2.append({
                            "label": "GeneralInfo",
                            "value": [
                                {
                                    "question1": dmet.s1,
                                    "question2": dmet.s2,
                                    "question3": dmet.s3
                                }
                            ]
                        })
                    if dmet.metric == "RaceEthnicity":
                        if dmet.s2 == "Employee":
                            cmeasNEW2.append({
                            "label": "RaceEthnicity",
                            "value": [
                                {
                                    "asianEmployees": dmet.m1,
                                    "hawaiianEmployees": dmet.m2,
                                    "blackEmployees": dmet.m3,
                                    "nativeEmployees": dmet.m4,
                                    "hispanicEmployees": dmet.m5,
                                    "whiteEmployees": dmet.m6,
                                    "multiEmployees": dmet.m7,
                                    "preferEmployees": dmet.m8,
                                    "otherEmployees": dmet.m9,
                                    "otherTextEmployees": dmet.s1
                                }
                            ]
                            })
                        if dmet.s2 == "C Suite":
                            cmeasNEW2.append({
                            "label": "RaceEthnicity",
                            "value": [
                                {
                                    "asianCSuite": dmet.m1,
                                    "hawaiianCSuite": dmet.m2,
                                    "blackCSuite": dmet.m3,
                                    "nativeCSuite": dmet.m4,
                                    "hispanicCSuite": dmet.m5,
                                    "whiteCSuite": dmet.m6,
                                    "multiCSuite": dmet.m7,
                                    "preferCSuite": dmet.m8,
                                    "otherCSuite": dmet.m9,
                                    "otherText": dmet.s1
                                }
                            ]
                            })
                        if dmet.s2 == "Board Member":
                            cmeasNEW2.append({
                            "label": "RaceEthnicity",
                            "value": [
                                {
                                    "asianBoard": dmet.m1,
                                    "hawaiianBoard": dmet.m2,
                                    "blackBoard": dmet.m3,
                                    "nativeBoard": dmet.m4,
                                    "hispanicBoard": dmet.m5,
                                    "whiteBoard": dmet.m6,
                                    "multiBoard": dmet.m7,
                                    "preferBoard": dmet.m8,
                                    "otherBoard": dmet.m9,
                                    "otherText": dmet.s1
                                }
                            ]
                            })
                    if dmet.metric == "Gender":
                        if dmet.s2 == "Employee":
                            cmeasNEW2.append({
                            "label": "Gender",
                            "value": [
                                {
                                    "manEmployees": dmet.m1,
                                    "womanEmployees": dmet.m2,
                                    "nonbiEmployees": dmet.m3,
                                    "transEmployees": dmet.m4,
                                    "preferEmployees": dmet.m5,
                                    "otherEmployees": dmet.m6,
                                    "otherText": dmet.s1
                                }
                            ]
                            })
                        if dmet.s2 == "C Suite":
                            cmeasNEW2.append({
                            "label": "Gender",
                            "value": [
                                {
                                    "manCSuite": dmet.m1,
                                    "womanCSuite": dmet.m2,
                                    "nonbiCSuite": dmet.m3,
                                    "transCSuite": dmet.m4,
                                    "preferCSuite": dmet.m5,
                                    "otherCSuite": dmet.m6,
                                    "otherText": dmet.s1
                                }
                            ]
                            })
                        if dmet.s2 == "Board Member":
                            cmeasNEW2.append({
                            "label": "Gender",
                            "value": [
                                {
                                    "manBoard": dmet.m1,
                                    "womanBoard": dmet.m2,
                                    "nonbiBoard": dmet.m3,
                                    "transBoard": dmet.m4,
                                    "preferBoard": dmet.m5,
                                    "otherBoard": dmet.m6,
                                    "otherText": dmet.s1
                                }
                            ]
                            })
                    if dmet.metric == "SexualOrientation":
                        if dmet.s2 == "Employee":
                            cmeasNEW2.append({
                            "label": "SexualOrientation",
                            "value": [
                                {
                                    "heteroEmployees": dmet.m1,
                                    "homoEmployees": dmet.m2,
                                    "biEmployees": dmet.m3,
                                    "preferEmployees": dmet.m4,
                                    "otherEmployees": dmet.m5,
                                    "otherText": dmet.s1
                                }
                            ]
                            })
                        if dmet.s2 == "C Suite":
                            cmeasNEW2.append({
                            "label": "SexualOrientation",
                            "value": [
                                {
                                    "heteroCSuite": dmet.m1,
                                    "homoCSuite": dmet.m2,
                                    "biCSuite": dmet.m3,
                                    "preferCSuite": dmet.m4,
                                    "otherCSuite": dmet.m5,
                                    "otherText": dmet.s1
                                }
                            ]
                            })
                        if dmet.s2 == "Board Member":
                            cmeasNEW2.append({
                            "label": "SexualOrientation",
                            "value": [
                                {
                                    "heteroBoard": dmet.m1,
                                    "homoBoard": dmet.m2,
                                    "biBoard": dmet.m3,
                                    "preferBoard": dmet.m4,
                                    "otherBoard": dmet.m5,
                                    "otherText": dmet.s1
                                }
                            ]
                            })
                    cmeasNEW.append({
                        "uuid": dmet.nano,
                        "email": dmet.email,
                        "results": cmeasNEW2
                    })
                    newMet = {
                        "label": "Results",
                        "metrics": cmeasNEW
                    }
                    mets.append(newMet)
                    target = {
                        "surveymeasure": mets
                    }
                    user.update(target)
                    callConnect.container9.upsert_item(body=user)
                else:
                    cmeasNEW2 = []
                    if dmet.metric == "GeneralInfo":
                        cmeasNEW2.append({
                            "label": "GeneralInfo",
                            "value": [
                                {
                                    "question1": dmet.s1,
                                    "question2": dmet.s2,
                                    "question3": dmet.s3
                                }
                            ]
                        })
                    if dmet.metric == "RaceEthnicity":
                        if dmet.s2 == "Employee":
                            cmeasNEW2.append({
                            "label": "RaceEthnicity",
                            "value": [
                                {
                                    "asianEmployees": dmet.m1,
                                    "hawaiianEmployees": dmet.m2,
                                    "blackEmployees": dmet.m3,
                                    "nativeEmployees": dmet.m4,
                                    "hispanicEmployees": dmet.m5,
                                    "whiteEmployees": dmet.m6,
                                    "multiEmployees": dmet.m7,
                                    "preferEmployees": dmet.m8,
                                    "otherEmployees": dmet.m9,
                                    "otherTextEmployees": dmet.s1
                                }
                            ]
                            })
                        if dmet.s2 == "C Suite":
                            cmeasNEW2.append({
                            "label": "RaceEthnicity",
                            "value": [
                                {
                                    "asianCSuite": dmet.m1,
                                    "hawaiianCSuite": dmet.m2,
                                    "blackCSuite": dmet.m3,
                                    "nativeCSuite": dmet.m4,
                                    "hispanicCSuite": dmet.m5,
                                    "whiteCSuite": dmet.m6,
                                    "multiCSuite": dmet.m7,
                                    "preferCSuite": dmet.m8,
                                    "otherCSuite": dmet.m9,
                                    "otherText": dmet.s1
                                }
                            ]
                            })
                        if dmet.s2 == "Board Member":
                            cmeasNEW2.append({
                            "label": "RaceEthnicity",
                            "value": [
                                {
                                    "asianBoard": dmet.m1,
                                    "hawaiianBoard": dmet.m2,
                                    "blackBoard": dmet.m3,
                                    "nativeBoard": dmet.m4,
                                    "hispanicBoard": dmet.m5,
                                    "whiteBoard": dmet.m6,
                                    "multiBoard": dmet.m7,
                                    "preferBoard": dmet.m8,
                                    "otherBoard": dmet.m9,
                                    "otherText": dmet.s1
                                }
                            ]
                            })
                    if dmet.metric == "Gender":
                        if dmet.s2 == "Employee":
                            cmeasNEW2.append({
                            "label": "Gender",
                            "value": [
                                {
                                    "manEmployees": dmet.m1,
                                    "womanEmployees": dmet.m2,
                                    "nonbiEmployees": dmet.m3,
                                    "transEmployees": dmet.m4,
                                    "preferEmployees": dmet.m5,
                                    "otherEmployees": dmet.m6,
                                    "otherText": dmet.s1
                                }
                            ]
                            })
                        if dmet.s2 == "C Suite":
                            cmeasNEW2.append({
                            "label": "Gender",
                            "value": [
                                {
                                    "manCSuite": dmet.m1,
                                    "womanCSuite": dmet.m2,
                                    "nonbiCSuite": dmet.m3,
                                    "transCSuite": dmet.m4,
                                    "preferCSuite": dmet.m5,
                                    "otherCSuite": dmet.m6,
                                    "otherText": dmet.s1
                                }
                            ]
                            })
                        if dmet.s2 == "Board Member":
                            cmeasNEW2.append({
                            "label": "Gender",
                            "value": [
                                {
                                    "manBoard": dmet.m1,
                                    "womanBoard": dmet.m2,
                                    "nonbiBoard": dmet.m3,
                                    "transBoard": dmet.m4,
                                    "preferBoard": dmet.m5,
                                    "otherBoard": dmet.m6,
                                    "otherText": dmet.s1
                                }
                            ]
                            })
                    if dmet.metric == "SexualOrientation":
                        if dmet.s2 == "Employee":
                            cmeasNEW2.append({
                            "label": "SexualOrientation",
                            "value": [
                                {
                                    "heteroEmployees": dmet.m1,
                                    "homoEmployees": dmet.m2,
                                    "biEmployees": dmet.m3,
                                    "preferEmployees": dmet.m4,
                                    "otherEmployees": dmet.m5,
                                    "otherText": dmet.s1
                                }
                            ]
                            })
                        if dmet.s2 == "C Suite":
                            cmeasNEW2.append({
                            "label": "SexualOrientation",
                            "value": [
                                {
                                    "heteroCSuite": dmet.m1,
                                    "homoCSuite": dmet.m2,
                                    "biCSuite": dmet.m3,
                                    "preferCSuite": dmet.m4,
                                    "otherCSuite": dmet.m5,
                                    "otherText": dmet.s1
                                }
                            ]
                            })
                        if dmet.s2 == "Board Member":
                            cmeasNEW2.append({
                            "label": "SexualOrientation",
                            "value": [
                                {
                                    "heteroBoard": dmet.m1,
                                    "homoBoard": dmet.m2,
                                    "biBoard": dmet.m3,
                                    "preferBoard": dmet.m4,
                                    "otherBoard": dmet.m5,
                                    "otherText": dmet.s1
                                }
                            ]
                            })

                    cmeasNEW.append({
                        "uuid": dmet.nano,
                        "email": dmet.email,
                        "results": cmeasNEW2
                    })
                
                    newMet = {
                        "label": "Results",
                        "metrics": cmeasNEW
                    }
                    mets.append(newMet)
                    target = {
                        "surveymeasure": mets
                    }
                    user.update(target)
                    callConnect.container9.upsert_item(body=user)
        else:
            user = {
                    "id": db_result["id"],
                    "surveymeasure": []
            }
            mets = [z for z in db_result["surveymeasure"] if z["label"] != "Results"]
            cmeasNEW2 = []

            if dmet.metric == "GeneralInfo":
                cmeasNEW2.append({
                    "label": "GeneralInfo",
                    "value": [
                        {
                            "question1": dmet.s1,
                            "question2": dmet.s2,
                            "question3": dmet.s3
                        }
                    ]
                })
            if dmet.metric == "RaceEthnicity":
                if dmet.s2 == "Employee":
                    cmeasNEW2.append({
                        "label": "RaceEthnicity",
                        "value": [
                            {
                                "asianEmployees": dmet.m1,
                                "hawaiianEmployees": dmet.m2,
                                "blackEmployees": dmet.m3,
                                "nativeEmployees": dmet.m4,
                                "hispanicEmployees": dmet.m5,
                                "whiteEmployees": dmet.m6,
                                "multiEmployees": dmet.m7,
                                "preferEmployees": dmet.m8,
                                "otherEmployees": dmet.m9,
                                "otherTextEmployees": dmet.s1
                            }
                            ]
                        })
                if dmet.s2 == "C Suite":
                    cmeasNEW2.append({
                    "label": "RaceEthnicity",
                    "value": [
                        {
                            "asianCSuite": dmet.m1,
                            "hawaiianCSuite": dmet.m2,
                            "blackCSuite": dmet.m3,
                            "nativeCSuite": dmet.m4,
                            "hispanicCSuite": dmet.m5,
                            "whiteCSuite": dmet.m6,
                            "multiCSuite": dmet.m7,
                            "preferCSuite": dmet.m8,
                            "otherCSuite": dmet.m9,
                            "otherText": dmet.s1
                        }
                    ]
                    })
                if dmet.s2 == "Board Member":
                    cmeasNEW2.append({
                    "label": "RaceEthnicity",
                    "value": [
                        {
                            "asianBoard": dmet.m1,
                            "hawaiianBoard": dmet.m2,
                            "blackBoard": dmet.m3,
                            "nativeBoard": dmet.m4,
                            "hispanicBoard": dmet.m5,
                            "whiteBoard": dmet.m6,
                            "multiBoard": dmet.m7,
                            "preferBoard": dmet.m8,
                            "otherBoard": dmet.m9,
                            "otherText": dmet.s1
                        }
                    ]
                    })
            if dmet.metric == "Gender":
                if dmet.s2 == "Employee":
                    cmeasNEW2.append({
                        "label": "Gender",
                        "value": [
                            {
                                "manEmployees": dmet.m1,
                                "womanEmployees": dmet.m2,
                                "nonbiEmployees": dmet.m3,
                                "transEmployees": dmet.m4,
                                "preferEmployees": dmet.m5,
                                "otherEmployees": dmet.m6,
                                "otherText": dmet.s1
                            }
                        ]
                        })
                if dmet.s2 == "C Suite":
                    cmeasNEW2.append({
                        "label": "Gender",
                        "value": [
                            {
                                "manCSuite": dmet.m1,
                                "womanCSuite": dmet.m2,
                                "nonbiCSuite": dmet.m3,
                                "transCSuite": dmet.m4,
                                "preferCSuite": dmet.m5,
                                "otherCSuite": dmet.m6,
                                "otherText": dmet.s1
                            }
                        ]
                    })
                if dmet.s2 == "Board Member":
                    cmeasNEW2.append({
                        "label": "Gender",
                        "value": [
                            {
                                "manBoard": dmet.m1,
                                "womanBoard": dmet.m2,
                                "nonbiBoard": dmet.m3,
                                "transBoard": dmet.m4,
                                "preferBoard": dmet.m5,
                                "otherBoard": dmet.m6,
                                "otherText": dmet.s1
                            }
                        ]
                    })
            if dmet.metric == "SexualOrientation":
                if dmet.s2 == "Employee":
                    cmeasNEW2.append({
                        "label": "SexualOrientation",
                        "value": [
                            {
                                "heteroEmployees": dmet.m1,
                                "homoEmployees": dmet.m2,
                                "biEmployees": dmet.m3,
                                "preferEmployees": dmet.m4,
                                "otherEmployees": dmet.m5,
                                "otherText": dmet.s1
                            }
                        ]
                    })
                if dmet.s2 == "C Suite":
                    cmeasNEW2.append({
                        "label": "SexualOrientation",
                        "value": [
                            {
                                "heteroCSuite": dmet.m1,
                                "homoCSuite": dmet.m2,
                                "biCSuite": dmet.m3,
                                "preferCSuite": dmet.m4,
                                "otherCSuite": dmet.m5,
                                "otherText": dmet.s1
                            }
                        ]
                    })
                if dmet.s2 == "Board Member":
                    cmeasNEW2.append({
                        "label": "SexualOrientation",
                        "value": [
                            {
                                "heteroBoard": dmet.m1,
                                "homoBoard": dmet.m2,
                                "biBoard": dmet.m3,
                                "preferBoard": dmet.m4,
                                "otherBoard": dmet.m5,
                                "otherText": dmet.s1
                            }
                        ]
                    })

            newMet = {
                "label": "Results",
                "metrics": cmeasNEW2
            }
            mets.append(newMet)
            target = {
                "surveymeasure": mets
            }
            user.update(target)
            callConnect.container9.upsert_item(body=user)

"""
Endpoint used to grab all of the carbon measure pages in the DB
"""
@diversityroute.post('/sendsurvey')
async def send_survey(dmet: SendSurvey):
    try:
        db_result = read_item(callConnect.container9, dmet.label, dmet.label)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /sendsurvey container9')
        return {"url": "/", "atype": False}
    
    if "surveymeasure" in db_result:
        if dmet.metric == "Results":
            user = {
                "id": db_result["id"],
                "surveymeasure": []
            }
            mets = [z for z in db_result["surveymeasure"] if z["label"] != "Results"]
            if ([z for z in db_result["surveymeasure"] if z["label"] == "Results"]):
                nmet = [z for z in db_result["surveymeasure"] if z["label"] == "Results"][0]
                
                
                if nmet:
                    cmeas = [f for f in nmet["metrics"]]
                    for i in range(0, len(dmet.emails)):
                        TO_EMAILS = [(dmet.emails[i])]
                        message = Mail(from_email=FROM_EMAIL, to_emails=TO_EMAILS)
                        message.dynamic_template_data = {
                            'Weblink': dmet.label,
                            'code': dmet.codes[i],
                            'company': dmet.companyName
                        }
                        message.template_id = TEMPLATE_ID4
                        
                        try:
                            sg = SendGridAPIClient(SENDGRID_API_KEY)
                            response = sg.send(message)
                            # code, body, headers = response.status_code, response.body, response.headers
                            
                        except Exception as e:
                            logging.error('This is an error message for /sendsurvey container9 Error: {0}.format(e)')
                        
                        cmeas.append({"uuid": dmet.codes[i], "email": dmet.emails[i], "results": []})

                    newMet = {
                        "label": "Results",
                        "metrics": cmeas
                    }
                    mets.append(newMet)
                    target = {
                        "surveymeasure": mets
                    }
                    user.update(target)
                    callConnect.container9.upsert_item(body=user)
            else:
                user = {
                        "id": db_result["id"],
                        "surveymeasure": []
                }
                cmeas = []
                mets = [z for z in db_result["surveymeasure"] if z["label"] != "Results"]

                for i in range(0, len(dmet.emails)):
                    TO_EMAILS = [(dmet.emails[i])]
                    
                    message = Mail(from_email=FROM_EMAIL, to_emails=TO_EMAILS)
                    message.dynamic_template_data = {
                        'Weblink': dmet.label,
                        'code': dmet.codes[i],
                        'company': dmet.companyName
                    }
                    message.template_id = TEMPLATE_ID4
                    
                    try:
                        sg = SendGridAPIClient(SENDGRID_API_KEY)
                        response = sg.send(message)
                        # code, body, headers = response.status_code, response.body, response.headers

                    except Exception as e:
                        logging.error('This is an error message for /sendsurvey container9 Error: {0}.format(e)')
                        
                    
                    cmeas.append({"uuid": dmet.codes[i], "email": dmet.emails[i]})

                newMet = {
                    "label": "Results",
                    "metrics": cmeas
                }
                mets.append(newMet)
                target = {
                    "surveymeasure": mets
                }
                user.update(target)
                callConnect.container9.upsert_item(body=user)
                




"""
Endpoint used to grab all of the carbon measure pages in the DB
"""
@diversityroute.post('/getsurveymeasure')
async def get_survey_measure(dmet: GetSurvey):
    try:
        db_result = read_item(callConnect.container9, dmet.label, dmet.label)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /getsurveymeasure container9')
        return {"url": "/", "atype": False}
    
    if "surveymeasure" in db_result:
        return {"smets": db_result["surveymeasure"]}


